@@ -19,6 +19,7 @@ class PublishFileType(Enum):
     VECTOR = 'vector'
     RASTER = 'raster'
     MODEL3D = 'model3d'
+    Tiles3D = 'tiles3d'
 
 class FileType(Enum):
     Compressed = 'Compressed'
@@ -36,6 +37,7 @@ class FileType(Enum):
     FileGDB = 'FileGDB'
     GeoTIFF = 'GeoTIFF'
     GeoJSON = 'GeoJSON'
+    ThreedTiles = 'ThreedTiles'
 
 class FileFormat(Enum):
     # Spatial Data Formats
@@ -270,14 +272,6 @@ class UserStatus(Enum):
     DISABLED = "Disabled"
 
 
-class AttachmentResourceType(Enum):
-    Map = "map"
-
-    Vector = "vector"
-
-    View = "view"
-
-
 class MaxLogPolicy(Enum):
     OverwriteFirstLog = "OverwriteFirstLog"
 
@@ -351,4 +345,88 @@ class UsageScale(Enum):
 class UsageParam(Enum):
     Traffict = 'traffic'
 
-    Calls = 'calls'
\ No newline at end of file
+    Calls = 'calls'
+
+
+class AnalysisDataType(Enum):
+    uint8 = 'uint8'
+    uint16 = 'uint16'
+    int16 = 'int16'
+    uint32 = 'uint32'
+    int32 = 'int32'
+    float32 = 'float32'
+    float64 = 'float64'
+
+
+class PolygonizeConnectivity(Enum):
+    connected_8 = 8
+    connected_4 = 4
+
+
+class AnalysisResampleMethod(Enum):
+    near = 'near'
+    bilinear = 'bilinear'
+    cubic = 'cubic'
+    cubicspline = 'cubicspline'
+    lanczos = 'lanczos'
+    average = 'average'
+    mode = 'mode'
+    max = 'max'
+    min = 'min'
+    med = 'med'
+    q1 = 'q1'
+    q3 = 'q3'
+    rms = 'rms'
+    sum = 'sum'
+
+
+class SlopeUnit(Enum):
+    degree = 'degree'
+    percent = 'percent'
+
+
+class AnalysisAlgorithm(Enum):
+    Horn = 'Horn'
+    ZevenbergenThorne = 'ZevenbergenThorne'
+
+
+class RangeBound(Enum):
+    left = 'left'
+    right = 'right'
+    both = 'both'
+    neither = 'neither'
+
+
+class DistanceUnit(Enum):
+    GEO = 'GEO'
+    PIXEL = 'PIXEL'
+
+
+class GroupByAggFunction(Enum):
+    COUNT = 'count'
+    SUM = 'sum'
+    MIN = 'min'
+    MAX = 'max'
+    AVG = 'avg'
+
+
+class NetworkTraceDirection(Enum):
+    UP = "up"
+    DOWN = "down"
+
+
+class SpatialAggFunction(Enum):
+    COLLECT = 'collect'
+    UNION = 'union'
+    EXTENT = 'extent'
+    MAKELINE = 'makeline'
+
+
+class SpatialPredicate(Enum):
+    INTERSECT = 'Intersect'
+    CONTAIN = 'Contain'
+    CROSS = 'Cross'
+    EQUAL = 'Equal'
+    OVERLAP = 'Overlap'
+    TOUCH = 'Touch'
+    WITHIN = 'Within'
\ No newline at end of file
