@@ -6,20 +6,17 @@ from .enums import FeatureType
 
 if TYPE_CHECKING:
     from .vectorlayer import VectorLayer
+    from .aio import AsyncGeoboxClient
+    from .aio.feature import AsyncFeature
+
 
 class Feature(Base):
-    """
-    A class representing a feature in a vector layer in Geobox.
 
-    This class provides functionality to create, manage, and manipulate features in a vector layer.
-    It supports various operations including CRUD operations on features, as well as advanced operations like transforming geometries.
-    It also provides properties to access the feature geometry and properties, and a method to transform the feature geometry.
-    """
     BASE_SRID = 3857
 
     def __init__(self, 
                  layer: 'VectorLayer', 
-                 srid: Optional[int] = 3857,
+                 srid: Optional[int] = BASE_SRID,
                  data: Optional[Dict] = {}):
         """
         Constructs all the necessary attributes for the Feature object.
@@ -33,7 +30,17 @@ class Feature(Base):
             >>> from geobox import GeoboxClient, Feature
             >>> client = GeoboxClient()
             >>> layer = client.get_vector(uuid="12345678-1234-5678-1234-567812345678")
-            >>> feature = Feature(layer=layer, srid=4326) # example srid set to 4326
+            >>> geojson = {
+            ...     "type": "Feature",
+            ...     "geometry": {
+            ...         "type": "Point",
+            ...         "coordinates": [58.4, 23.6]
+            ...     },
+            ...     "properties": {
+            ...         "name": "Test feature"
+            ...     }
+            ... }
+            >>> feature = Feature(layer=layer, data=geojson, srid=4326) # example srid set to 4326
             >>> feature.save()
         """
         super().__init__(api=layer.api)
@@ -68,8 +75,9 @@ class Feature(Base):
         Returns:
             str: A string representation of the Feature object.
         """
-        return f"Feature(id={self.id}, type={self.feature_type})"
-    
+        feature_id = getattr(self, "id", "-1")
+        return f"Feature(id={feature_id}, type={self.feature_type})"
+        
 
     def __getattr__(self, name: str) -> Any:
         """
@@ -163,10 +171,10 @@ class Feature(Base):
     @property
     def length(self) -> float:
         """
-        Returns the length of thefeature geometry (geometry package extra is required!)
+        Returns the length of the feature geometry (geometry package extra is required!)
 
         Returns:
-            float: the length of thefeature geometry
+            float: the length of the feature geometry
 
         Example:
             >>> from geobox import GeoboxClient
@@ -220,18 +228,28 @@ class Feature(Base):
             >>> feature.save()
         """
         data = self.data.copy()
+        srid = self.srid
+
         try:
             if self.id:
                 if self.srid != self.BASE_SRID:
-                    self.data['geometry'] = self.original_geometry
+                    self = self.transform(self.BASE_SRID)
+                self.data['geometry'] = self.original_geometry
                 self.update(self.data)
                 self.coordinates = data['geometry']['coordinates']
         except AttributeError:
+            if self.srid != self.BASE_SRID:
+                self = self.transform(self.BASE_SRID)
             endpoint = urljoin(self.layer.endpoint, 'features/')
-            response = self.layer.api.post(endpoint, data)
+            request_data = self.data.copy()
+            response = self.layer.api.post(endpoint, request_data)
             self.endpoint = urljoin(self.layer.endpoint, f'features/{response["id"]}/')        
             self.data.update(response)
 
+        self.data['geometry'] = data['geometry']
+        self._srid = srid
+
+
 
     def delete(self) -> None:
         """
@@ -247,7 +265,7 @@ class Feature(Base):
             >>> feature = layer.get_feature(id=1)
             >>> feature.delete()
         """
-        super().delete(self.endpoint)
+        super()._delete(self.endpoint)
 
 
     def update(self, geojson: Dict) -> Dict:
@@ -266,11 +284,11 @@ class Feature(Base):
             >>> layer = client.get_vector(uuid="12345678-1234-5678-1234-567812345678")
             >>> feature = layer.get_feature(id=1)
             >>> geojson = {
-                "geometry": {
-                    "type": "Point",
-                    "coordinates": [10, 20]
-                }
-            }
+            ...     "geometry": {
+            ...         "type": "Point",
+            ...         "coordinates": [10, 20]
+            ...     }
+            ... }
             >>> feature.update(geojson)
         """
         return super()._update(self.endpoint, geojson, clean=False)
@@ -506,3 +524,26 @@ class Feature(Base):
         return self
 
 
+    def to_async(self, async_client: 'AsyncGeoboxClient') -> 'AsyncFeature':
+        """
+        Switch to async version of the feature instance to have access to the async methods
+
+        Args:
+            async_client (AsyncGeoboxClient): The async version of the GeoboxClient instance for making requests.
+
+        Returns:
+            AsyncFeature: the async instance of the feature.
+
+        Example:
+            >>> from geobox import Geoboxclient
+            >>> from geobox.aio import AsyncGeoboxClient
+            >>> client = GeoboxClient()
+            >>> layer = client.get_vector(uuid="12345678-1234-5678-1234-567812345678")
+            >>> feature = layer.get_feature(id=1, srid=3857)
+            >>> async with AsyncGeoboxClient() as async_client:
+            >>>     async_feature = feature.to_async(async_client)
+        """
+        from .aio.feature import AsyncFeature
+
+        async_layer = self.layer.to_async(async_client=async_client)
+        return AsyncFeature(layer=async_layer, srid=self.srid, data=self.data)
\ No newline at end of file
