@@ -8,15 +8,12 @@ from .enums import FieldType
 if TYPE_CHECKING:
     from .api import GeoboxClient
     from .vectorlayer import VectorLayer
+    from .aio import AsyncGeoboxClient
+    from .aio.field import AsyncField
+
 
 class Field(Base):
-    """
-    A class representing a field in a vector layer in Geobox.
 
-    This class provides functionality to create, manage, and manipulate fields in a vector layer.
-    It supports various operations including CRUD operations on fields, as well as advanced operations like getting unique values, statistics, and updating fields.
-    It also provides properties to access the field data, and a method to update the field.
-    """
     def __init__(self, 
                  layer: 'VectorLayer',
                  data_type: 'FieldType',
@@ -30,17 +27,6 @@ class Field(Base):
             data_type (FieldType): type of the field
             field_id (int): the id of the field
             data (Dict, optional): The data of the field.
-
-        Example:
-            >>> from geobox import GeoboxClient
-            >>> from geobox.field import Field
-            >>> client = GeoboxClient()
-            >>> layer = client.get_vector(uuid="12345678-1234-5678-1234-567812345678")
-            >>> field_data = {
-            ...     "name": "test"
-            ... }
-            >>> field = Field(layer=layer, data_type=FieldType.Integere, data=field_data)
-            >>> field.save()
         """
         super().__init__(api=layer.api, data=data)
         self.layer = layer
@@ -178,7 +164,7 @@ class Field(Base):
             >>> field = layer.get_field(name='test')
             >>> field.delete()
         """
-        super().delete(self.endpoint)
+        super()._delete(self.endpoint)
         self.field_id = None
 
 
@@ -202,7 +188,7 @@ class Field(Base):
             >>> from geobox.field import Field
             >>> client = GeoboxClient()
             >>> layer = client.get_vector(uuid="12345678-1234-5678-1234-567812345678")
-            >>> field = Field(layer=layer, data_type=FieldType.String)
+            >>> field = layer.get_field(name='test')
             >>> field.update(name="my_field", display_name="My Field", description="My Field Description")
         """       
         data = {
@@ -234,12 +220,12 @@ class Field(Base):
         return self.layer.api.get(endpoint)
 
 
-    def get_field_unique_values_numbers(self) -> Dict:
+    def get_field_unique_values_numbers(self) -> int:
         """
-        Get the unique values of the field.
+        Get the count of unique values of the field.
 
         Returns:
-            Dict: The response data.
+            int: The count of the field unique values.
 
         Example:
             >>> from geobox import GeoboxClient
@@ -307,3 +293,29 @@ class Field(Base):
 
         self.save()
         return self.domain
+
+
+    def to_async(self, async_client: 'AsyncGeoboxClient') -> 'AsyncField':
+        """
+        Switch to async version of the field instance to have access to the async methods
+
+        Args:
+            async_client (AsyncGeoboxClient): The async version of the GeoboxClient instance for making requests.
+
+        Returns:
+            AsyncField: the async instance of the field.
+
+        Example:
+            >>> from geobox import Geoboxclient
+            >>> from geobox.aio import AsyncGeoboxClient
+            >>> from geobox.field import Field
+            >>> client = GeoboxClient()
+            >>> layer = client.get_vector(uuid="12345678-1234-5678-1234-567812345678")
+            >>> field = layer.get_field(name='test')
+            >>> async with AsyncGeoboxClient() as async_client:
+            >>>     async_field = field.to_async(async_client)
+        """
+        from .aio.field import AsyncField
+
+        async_layer = self.layer.to_async(async_client=async_client)
+        return AsyncField(layer=async_layer, data_type=self.data_type, field_id=self.field_id, data=self.data)
\ No newline at end of file
