@@ -5,26 +5,22 @@ import mimetypes
 from geobox.exception import ValidationError
 import requests
 import sys
-from pathlib import Path
 
 from .base import Base
 from .enums import FileFormat, PublishFileType, InputGeomType, FileType
-from .utils import clean_data
+from .utils import clean_data, get_unique_filename, get_save_path
 from .task import Task
 from .feature import Feature
 
 if TYPE_CHECKING:
     from . import GeoboxClient 
     from .user import User
+    from .aio import AsyncGeoboxClient
+    from .aio.file import AsyncFile
+
 
 class File(Base):
-    """
-    A class to interact with files in Geobox.
 
-    This class provides functionality to interact with files in Geobox.
-    It supports various operations including CRUD operations on files, as well as advanced operations like publishing, and sharing files.
-    It also provides properties to access the file data, and a method to download the file.
-    """
     BASE_ENDPOINT: str = 'files/'
 
     def __init__(self, 
@@ -35,7 +31,7 @@ class File(Base):
         Constructs all the necessary attributes for the File object.
 
         Args:
-            api (Api): The API instance.
+            api (GeoboxClient): The GeoboxClient instance.
             uuid (str): The UUID of the file.
             data (Dict, optional): The data of the file.
         """
@@ -92,7 +88,7 @@ class File(Base):
         Upload a file to the GeoBox API.
 
         Args:
-            api (GeoboxClient): The API instance.
+            api (GeoboxClient): The GeoboxClient instance.
             path (str): The path to the file to upload.
             user_id (int, optional): specific user. privileges required.
             scan_archive (bool, optional): Whether to scan the archive for layers. default: True
@@ -143,7 +139,7 @@ class File(Base):
             q (str): query filter based on OGC CQL standard. e.g. "field1 LIKE '%GIS%' AND created_at > '2021-01-01'"
             search (str): search term for keyword-based searching among search_fields or all textual fields if search_fields does not have value. NOTE: if q param is defined this param will be ignored.
             search_fields (str): comma separated list of fields for searching
-            order_by (str): comma separated list of fields for sorting results [field1 A|D, field2 A|D, …]. e.g. name A, type D.NOTE: "A" denotes ascending order and "D" denotes descending order.
+            order_by (str): comma separated list of fields for sorting results [field1 A|D, field2 A|D, …]. e.g. name A, type D. NOTE: "A" denotes ascending order and "D" denotes descending order.
             return_count (bool): if true, the total number of results will be returned. default is False.
             skip (int): number of results to skip. default is 0.
             limit (int): number of results to return. default is 10.
@@ -182,7 +178,7 @@ class File(Base):
         Retrieves a file by its UUID.
 
         Args:
-            api (Api): The API instance.
+            api (Api): The GeoboxClient instance.
             uuid (str): The UUID of the file.
             user_id (int, optional): specific user. privileges required.
 
@@ -229,37 +225,7 @@ class File(Base):
             >>> files = client.get_files_by_name(name='test')
         """
         return cls.get_files(api, q=f"name = '{name}'", user_id=user_id)
-    
 
-    def _get_save_path(self, save_path: str = None) -> str:
-        """
-        Get the path where the file should be saved.
-
-        Args:
-            save_path (str, optional): The path to save the file.
-
-        Returns:
-            str: The path where the file is saved.
-        
-        Raises:
-            ValueError: If save_path does not end with a '/'.
-
-        Example:
-            >>> from geobox import GeoboxClient
-            >>> from geobox.file import File
-            >>> from geobox import GeoboxClient
-            >>> client = GeoboxClient()
-            >>> file_path = File.get_file(client, uuid="12345678-1234-5678-1234-567812345678")
-        """
-        # If save_path is provided, check if it ends with a '/'
-        if save_path and save_path.endswith('/'):
-            return f'{save_path}'
-        
-        if save_path and not save_path.endswith('/'):
-            raise ValueError("save_path must end with a '/'")
-        
-        return os.getcwd()
-    
 
     def _get_file_name(self, response: requests.Response) -> str:
         """
@@ -301,7 +267,7 @@ class File(Base):
                 )
 
 
-    def download(self, save_path: str = None, progress_bar: bool = True) -> str:
+    def download(self, save_path: str = None, progress_bar: bool = True, file_name: str = None, overwrite: bool = False) -> str:
         """
         Download a file and save it to the specified path.
         
@@ -310,6 +276,8 @@ class File(Base):
                                     If not provided, it saves to the current working directory
                                     using the original filename and appropriate extension.
             progress_bar (bool, optional): Whether to show a progress bar. default: True
+            file_name (str, optional): the downloaded file name.
+            overwrite (bool, optional): whether to overwrite the downloaded file if it exists on the save path. default is False.
         
         Returns:
             str: Path where the file was saved
@@ -328,12 +296,14 @@ class File(Base):
         if not self.uuid:
             raise ValueError("File UUID is required to download the file")
         
-        save_path = self._get_save_path(save_path)
+        save_path = get_save_path(save_path)
         os.makedirs(os.path.dirname(save_path), exist_ok=True)
         
         with self.api.get(f"{self.endpoint}download/", stream=True) as response:
-            file_name = self._get_file_name(response)
+            file_name = self._get_file_name(response) if not file_name else file_name
             full_path = f"{save_path}/{file_name}"
+            if os.path.exists(full_path) and not overwrite:
+                full_path = get_unique_filename(save_path, file_name)
             with open(full_path, 'wb') as f:
                 pbar = self._create_progress_bar() if progress_bar else None
                 for chunk in response.iter_content(chunk_size=8192):
@@ -361,7 +331,7 @@ class File(Base):
             >>> file = File.get_file(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> file.delete()
         """
-        return super().delete(self.endpoint)
+        return super()._delete(self.endpoint)
 
 
     def publish(self, 
@@ -381,7 +351,7 @@ class File(Base):
 
         Args:
             name (str): The name of the layer.
-            publish_as (PublishFileType): The type of layer to publish as.
+            publish_as (PublishFileType, optional): The type of layer to publish as.
             input_geom_type (InputGeomType, optional): The geometry type of the layer.
             input_layer (str, optional): The name of the input layer.
             input_dataset (str, optional): The name of the input dataset.
@@ -429,6 +399,9 @@ class File(Base):
                         FileType(self.layers[0]['format']).value in ['GLB']):
                 publish_as = PublishFileType.MODEL3D
 
+            elif self.file_type.value in ['ThreedTiles']:
+                publish_as = PublishFileType.Tiles3D
+
             else:
                 raise ValidationError('Unknown format')
 
@@ -518,3 +491,27 @@ class File(Base):
             'limit': limit
         }
         return super()._get_shared_users(self.endpoint, params)
+
+
+    def to_async(self, async_client: 'AsyncGeoboxClient') -> 'AsyncFile':
+        """
+        Switch to async version of the file instance to have access to the async methods
+
+        Args:
+            async_client (AsyncGeoboxClient): The async version of the GeoboxClient instance for making requests.
+
+        Returns:
+            AsyncFile: the async instance of the file.
+
+        Example:
+            >>> from geobox import Geoboxclient
+            >>> from geobox.aio import AsyncGeoboxClient
+            >>> from geobox.file import File
+            >>> client = GeoboxClient()
+            >>> file = File.get_file(client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> async with AsyncGeoboxClient() as async_client:
+            >>>     async_file = file.to_async(async_client)
+        """
+        from .aio.file import AsyncFile
+
+        return AsyncFile(api=async_client, uuid=self.uuid, data=self.data)
\ No newline at end of file
