@@ -2,13 +2,18 @@ from typing import Dict, List, Optional, Union, TYPE_CHECKING
 from urllib.parse import urljoin, urlencode
 
 from .base import Base
-from .utils import clean_data
+from .utils import clean_data, join_url_params
 from .model3d import Model
+from .file import File
+from .feature import Feature
 
 if TYPE_CHECKING:
     from . import GeoboxClient
     from .user import User
     from .task import Task
+    from .attachment import Attachment
+    from .aio import AsyncGeoboxClient
+    from .aio.map import Map as AsyncMap
 
 
 class Map(Base):
@@ -237,7 +242,7 @@ class Map(Base):
             >>> map = Map.get_map(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> map.delete()
         """
-        super().delete(self.endpoint)
+        super()._delete(self.endpoint)
 
 
     @property
@@ -274,10 +279,8 @@ class Map(Base):
             >>> client = GeoboxClient()
             >>> map = Map.get_map(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> map.thumbnail
-            'https://example.com/thumbnail.png'
         """
-        endpoint = f"{self.api.base_url}{self.endpoint}thumbnail.png"
-        return endpoint
+        return super()._thumbnail()
     
 
     def set_readonly(self, readonly: bool) -> None:
@@ -351,6 +354,10 @@ class Map(Base):
         endpoint = urljoin(self.api.base_url, f'{self.endpoint}wmts/')
         if scale:
             endpoint = f"{endpoint}?scale={scale}"
+
+        if not self.api.access_token and self.api.apikey:
+            endpoint = join_url_params(endpoint, {"apikey": self.api.apikey})
+
         return endpoint
 
     
@@ -567,11 +574,30 @@ class Map(Base):
             'view_settings': {},
             'toc_settings': []
         })
+    
+
+    def update_settings(self, settings: Dict) -> Dict:
+        """
+        Update the settings
+
+        settings (Dict): settings dictionary
+
+        Returns:
+            Dict: updated settings
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> client = GeoboxClient()
+            >>> map1 = client.get_map(uuid="12345678-1234-5678-1234-567812345678")
+            >>> map2 = client.get_map(uuid="12345678-1234-5678-1234-567812345678")
+            >>> map1.update_settings(map2.settings)
+        """
+        return super()._set_settings(self.endpoint, settings)    
 
 
     def set_settings(self, **kwargs) -> Dict:
         """
-        Set the settings of the map.
+        Set the settings of the map using keywords
 
         Keyword Args:
             map_unit (str): 'latlng' | 'utm'.
@@ -610,6 +636,13 @@ class Map(Base):
 
         Returns:
             Dict: The response of the API.
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> from geobox.map import Map
+            >>> client = GeoboxClient()
+            >>> map = Map.get_map(uuid="12345678-1234-5678-1234-567812345678")
+            >>> map.set_settings(zoom=10)
         """
         general_settings = {'map_unit', 'base_map', 'flash_color', 'highlight_color', 
                             'selection_color', 'selectable_layers', 'calendar_type', 'custom_basemaps', 'show_maptip_on'}
@@ -729,7 +762,7 @@ class Map(Base):
         if not response or json:
             return response
         else:
-            return [Model(self.api, model['obj'], model) for model in response['objects']]
+            return [Model(self.api, model['obj'], model) for model in response['objects'] if response.get('objects')]
     
 
     def set_models(self, data: Dict) -> List['Model']:
@@ -764,7 +797,7 @@ class Map(Base):
         """
         endpoint = urljoin(self.endpoint, 'models/')
         response = self.api.put(endpoint, data)
-        return [Model(self.api, model['obj'], model) for model in response['objects']]
+        return [Model(self.api, model['obj'], model) for model in response['objects'] if response.get('objects')]
 
 
     def add_model(self, 
@@ -856,4 +889,144 @@ class Map(Base):
             >>> map.image_tile_url()
             >>> map.image_tile_url(x=1, y=2, z=3, format='.pbf')
         """
-        return f"{self.BASE_ENDPOINT}{self.endpoint}{z}/{x}/{y}{format}"
+        endpoint = f"{self.api.base_url}{self.endpoint}tiles/{z}/{x}/{y}{format}"
+
+        if not self.api.access_token and self.api.apikey:
+            endpoint = f'{endpoint}?apikey={self.api.apikey}'
+
+        return endpoint
+    
+
+    def export_map_to_image(self, bbox: List, width: int, height: int) -> 'Task':
+        """
+        Export the map to image
+
+        Args:
+            bbox (List): e.g. [50.275, 35.1195, 51.4459, 36.0416]
+            width (int): minimum: 10, maximum: 10000
+            height (int): minimum: 10, maximum: 10000
+
+        Returns:
+            Task: the task object
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> from geobox.map import Map
+            >>> client = GeoboxClient()
+            >>> map = Map.get_map(client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> task = map.export_map_to_image(bbox=[50.275, 35.1195, 51.4459, 36.0416],
+            ...                                 width=1024,
+            ...                                 height=1024)
+        """
+        data = clean_data({
+            'uuid': self.uuid,
+            'bbox': bbox,
+            'width': width,
+            'height': height
+        })
+        query_string = urlencode(data)
+        endpoint = urljoin(self.endpoint, 'export/')
+        endpoint = f"{endpoint}?{query_string}"
+        response = self.api.post(endpoint)
+        return self.api.get_task(response['task_id'])
+
+
+    def get_attachments(self, **kwargs) -> List['Attachment']:
+        """
+        Get the resouces attachments
+
+        Keyword Args:
+            element_id (str): the id of the element with attachment.
+            search (str): search term for keyword-based searching among all textual fields.
+            order_by (str): comma separated list of fields for sorting results [field1 A|D, field2 A|D, …]. e.g. name A, type D. NOTE: "A" denotes ascending order and "D" denotes descending order.
+            skip (int): Number of items to skip. default is 0.
+            limit (int): Number of items to return. default is 10.
+            return_count (bool): Whether to return total count. default is False.
+
+        Returns:
+            List[Attachment] | int: A list of attachments instances or the total number of attachments.
+
+        Raises:
+            TypeError: if the resource type is not supported
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> from geobox.map import Map
+            >>> client = GeoboxClient()
+            >>> map = Map.get_map(client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> map.get_attachments()
+        """
+        from .attachment import Attachment
+
+        return Attachment.get_attachments(self.api, resource=self, **kwargs)
+    
+    
+    def create_attachment(self, 
+                            name: str, 
+                            loc_x: int,
+                            loc_y: int,
+                            file: 'File',
+                            feature: 'Feature' = None,
+                            display_name: str = None, 
+                            description: str = None) -> 'Attachment':
+        """
+        Create a new Attachment.
+
+        Args:
+            name (str): The name of the scene.
+            loc_x (int): x parameter of the attachment location.
+            loc_y (int): y parameter of the attachment location.
+            file (File): the file object.
+            feature (Feature, optional): the feature object.
+            display_name (str, optional): The display name of the scene.
+            description (str, optional): The description of the scene.
+
+        Returns:
+            Attachment: The newly created Attachment instance.
+
+        Raises:
+            ValidationError: If the Attachment data is invalid.
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> from geobox.map import Map
+            >>> client = GeoboxClient()
+            >>> map = Map.get_map(client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> file = client.get_files()[0]
+            >>> map.create_attachment(name='test', loc_x=10, loc_y=10, file=file)
+        """
+        from .attachment import Attachment
+
+        return Attachment.create_attachment(self.api,
+                                            name=name,
+                                            loc_x=loc_x,
+                                            loc_y=loc_y,
+                                            resource=self,
+                                            file=file,
+                                            feature=feature,
+                                            display_name=display_name,
+                                            description=description)
+    
+
+    def to_async(self, async_client: 'AsyncGeoboxClient') -> 'AsyncMap':
+        """
+        Switch to async version of the map instance to have access to the async methods
+
+        Args:
+            async_client (AsyncGeoboxClient): The async version of the GeoboxClient instance for making requests.
+
+        Returns:
+            AsyncMap: the async instance of the map.
+
+        Example:
+            >>> from geobox import Geoboxclient
+            >>> from geobox.aio import AsyncGeoboxClient
+            >>> from geobox.map import Map
+            >>> client = GeoboxClient()
+            >>> map = Map.get_map(client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> async with AsyncGeoboxClient() as async_client:
+            >>>     async_map = map.to_async(async_client)
+        """
+        from .aio.map import AsyncMap
+
+        return AsyncMap(api=async_client, uuid=self.uuid, data=self.data)
\ No newline at end of file
