@@ -8,15 +8,12 @@ if TYPE_CHECKING:
     from . import GeoboxClient
     from .user import User
     from .task import Task
+    from .aio import AsyncGeoboxClient
+    from .aio.mosaic import AsyncMosaic
+
 
 class Mosaic(Raster):
-    """
-    A class to represent a Mosaic in Geobox.
 
-    This class provides methods to interact with the mosaic in Geobox.
-    It inherits from the Raster class and provides additional methods to interact with the mosaic.
-    It also provides properties to access the mosaic data, and a method to update the mosaic.
-    """
     BASE_ENDPOINT: str = 'mosaics/'
 
     def __init__(self, 
@@ -227,7 +224,7 @@ class Mosaic(Raster):
             >>> from geobox.mosaic import Mosaic
             >>> client = GeoboxClient()
             >>> mosaic = Mosaic.get_mosaic(client, uuid="12345678-1234-5678-1234-567812345678")
-            >>> mosaic.update_mosaic(name='new_name', display_name='new_display_name', description='new_description', pixel_selection='new_pixel_selection', min_zoom=10)
+            >>> mosaic.update(name='new_name', display_name='new_display_name', description='new_description', pixel_selection='new_pixel_selection', min_zoom=10)
         """
         data = {
             'name': kwargs.get('name'),
@@ -253,7 +250,7 @@ class Mosaic(Raster):
             >>> mosaic = Mosaic.get_mosaic(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> mosaic.delete()
         """
-        super().delete()
+        super()._delete(self.endpoint)
     
 
     @property
@@ -271,7 +268,7 @@ class Mosaic(Raster):
             >>> mosaic = Mosaic.get_mosaic(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> mosaic.thumbnail
         """
-        return super().thumbnail
+        return super()._thumbnail(format="")
 
 
     def get_point(self, lat: float, lng: float) -> List[float]:
@@ -295,14 +292,14 @@ class Mosaic(Raster):
         return super().get_point(lat, lng)
 
 
-    def get_render_png_url(self, x: int, y: int, z: int, **kwargs) -> str:
+    def get_render_png_url(self, x: int = '{x}', y: int = '{y}', z: int = '{z}', **kwargs) -> str:
         """
         Get the tile render URL of the mosaic.
 
         Args:
-            x (int): The x coordinate of the tile.
-            y (int): The y coordinate of the tile.
-            z (int): The zoom level of the tile.
+            x (int, optional): The x coordinate of the tile.
+            y (int, optional): The y coordinate of the tile.
+            z (int, optional): The zoom level of the tile.
 
         Keyword Args:
             indexes (str, optional): list of comma separated band indexes to be rendered. e.g. 1, 2, 3
@@ -326,14 +323,14 @@ class Mosaic(Raster):
         return super().get_render_png_url(x, y, z, **kwargs)
     
 
-    def get_tile_png_url(self, x: int, y: int, z: int) -> str:
+    def get_tile_png_url(self, x: int = '{x}', y: int = '{y}', z: int = '{z}') -> str:
         """
         Get the tile PNG URL of the mosaic.
 
         Args:
-            x (int): The x coordinate of the tile.
-            y (int): The y coordinate of the tile.
-            z (int): The zoom level of the tile.
+            x (int, optional): The x coordinate of the tile.
+            y (int, optional): The y coordinate of the tile.
+            z (int, optional): The zoom level of the tile.
 
         Returns:
             str: The tile PNG URL of the mosaic.
@@ -401,6 +398,25 @@ class Mosaic(Raster):
         """
         return super().settings
     
+
+    def update_settings(self, settings: Dict) -> Dict:
+        """
+        Update the settings
+
+        settings (Dict): settings dictionary
+
+        Returns:
+            Dict: updated settings
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> client = GeoboxClient()
+            >>> mosaic1 = client.get_mosaic(uuid="12345678-1234-5678-1234-567812345678")
+            >>> mosaic2 = client.get_mosaic(uuid="12345678-1234-5678-1234-567812345678")
+            >>> mosaic1.update_settings(mosaic2.settings)
+        """
+        return super().update_settings(settings)  
+    
     
     def set_settings(self, **kwargs) -> None:
         """
@@ -654,3 +670,27 @@ class Mosaic(Raster):
             >>> mosaic.cache_size
         """
         return super().cache_size
+    
+
+    def to_async(self, async_client: 'AsyncGeoboxClient') -> 'AsyncMosaic':
+        """
+        Switch to async version of the mosaic instance to have access to the async methods
+
+        Args:
+            async_client (AsyncGeoboxClient): The async version of the GeoboxClient instance for making requests.
+
+        Returns:
+            AsyncMosaic: the async instance of the mosaic.
+
+        Example:
+            >>> from geobox import Geoboxclient
+            >>> from geobox.aio import AsyncGeoboxClient
+            >>> from geobox.mosaic import Mosaic
+            >>> client = GeoboxClient()
+            >>> mosaic = Mosaic.get_mosaic(client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> async with AsyncGeoboxClient() as async_client:
+            >>>     async_mosaic = mosaic.to_async(async_client)
+        """
+        from .aio.mosaic import AsyncMosaic
+
+        return AsyncMosaic(api=async_client, uuid=self.uuid, data=self.data)
