@@ -9,11 +9,11 @@ from .enums import QueryResultType, QueryGeometryType, QueryParamType
 if TYPE_CHECKING:
     from . import GeoboxClient
     from .user import User
+    from .aio import AsyncGeoboxClient
+    from .aio.query import AsyncQuery
 
 class Query(Base):
-    """
-    A class to interact with queries in GeoBox.
-    """
+
     BASE_ENDPOINT: str = 'queries/'
 
     def __init__(self, 
@@ -83,6 +83,7 @@ class Query(Base):
             >>> client = GeoboxClient()
             >>> query = Query.get_query(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> query.sql = 'SELECT * FROM some_layer'
+            >>> query.save()
         """
         self.data['sql'] = value
 
@@ -126,6 +127,7 @@ class Query(Base):
             >>> client = GeoboxClient()
             >>> query = Query.get_query(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> query.params = [{'name': 'layer', 'value': '12345678-1234-5678-1234-567812345678', 'type': 'Layer'}]
+            >>> query.save()
         """
         if not isinstance(self.data.get('params'), list):
             self.data['params'] = []
@@ -179,7 +181,7 @@ class Query(Base):
 
 
     @classmethod
-    def create_query(cls, api: 'GeoboxClient', name: str, display_name: str = None, sql: str = None, params: List = None) -> 'Query':
+    def create_query(cls, api: 'GeoboxClient', name: str, display_name: str = None, description:str = None, sql: str = None, params: List = None) -> 'Query':
         """
         Creates a new query.
 
@@ -187,6 +189,7 @@ class Query(Base):
             api (Api): The GeoboxClient instance for making requests.
             name (str): The name of the query.
             display_name (str, optional): The display name of the query.
+            description (str, optional): The description of the query.
             sql (str, optional): The SQL statement for the query.
             params (list, optional): The parameters for the SQL statement.
 
@@ -204,6 +207,7 @@ class Query(Base):
         data = {
             "name": name,
             "display_name": display_name,
+            "description": description,
             "sql": sql,
             "params": params
         }
@@ -342,9 +346,8 @@ class Query(Base):
             or
             >>> query = client.get_query(uuid="12345678-1234-5678-1234-567812345678")
             >>> query.add_param(name='param_name', value='param_value', type=QueryParamType.LAYER)
+            >>> query.save()
         """
-        self._check_access()
-        
         self.params.append({
             'name': name,
             'value': value,
@@ -376,9 +379,8 @@ class Query(Base):
             or
             >>> query = client.get_query(uuid="12345678-1234-5678-1234-567812345678")
             >>> query.remove_param(name='param_name')
+            >>> query.save()
         """
-        self._check_access()
-        
         for i, param in enumerate(self.params):
             if param.get('name') == name:
                 self.params.pop(i)
@@ -422,9 +424,7 @@ class Query(Base):
             or
             >>> query = client.get_query(uuid="12345678-1234-5678-1234-567812345678")
             >>> query.execute(f='json')
-        """
-        self._check_access()
-        
+        """        
         if not self.sql:
             raise ValueError('"sql" parameter is required for this action!') 
         if not self.params:
@@ -497,7 +497,6 @@ class Query(Base):
             >>> from geobox.query import Query
             >>> client = GeoboxClient()
             >>> query = Query.get_query(client, uuid="12345678-1234-5678-1234-567812345678")
-            >>> query.sql = "SELECT * FROM some_layer"
             >>> query.save()
         """
         self.params = [item for item in self.params if item.get('value')]
@@ -529,7 +528,7 @@ class Query(Base):
             >>> query.delete()
         """
         self._check_access()
-        super().delete(self.endpoint)
+        super()._delete(self.endpoint)
 
 
     def share(self, users: List['User']) -> None:
@@ -618,10 +617,15 @@ class Query(Base):
 
         Returns:
             str: The thumbnail URL.
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> from geobox.query import Query
+            >>> client = GeoboxClient()
+            >>> query = Query.get_query(client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> query.thumbnail
         """
-        self._check_access()
-        endpoint = f'{self.api.base_url}{self.endpoint}thumbnail.png'
-        return endpoint
+        return super()._thumbnail()
 
 
     def save_as_layer(self, layer_name: str, layer_type: 'QueryGeometryType' = None) -> Task:
@@ -645,8 +649,6 @@ class Query(Base):
             >>> query = Query.get_query(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> query.save_as_layer(layer_name='test')
         """
-        self._check_access()
-
         params = [{
             "name": item.get('name'),
             "type": item.get('type'),
@@ -664,3 +666,27 @@ class Query(Base):
         response = self.api.post(endpoint, data)
         task = Task.get_task(self.api, response.get('task_id'))
         return task
+
+
+    def to_async(self, async_client: 'AsyncGeoboxClient') -> 'AsyncQuery':
+        """
+        Switch to async version of the query instance to have access to the async methods
+
+        Args:
+            async_client (AsyncGeoboxClient): The async version of the GeoboxClient instance for making requests.
+
+        Returns:
+            AsyncQuery: the async instance of the query.
+
+        Example:
+            >>> from geobox import Geoboxclient
+            >>> from geobox.aio import AsyncGeoboxClient
+            >>> from geobox.query import Query
+            >>> client = GeoboxClient()
+            >>> query = Query.get_query(client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> async with AsyncGeoboxClient() as async_client:
+            >>>     async_query = query.to_async(async_client)
+        """
+        from .aio.query import AsyncQuery
+
+        return AsyncQuery(api=async_client, uuid=self.uuid, data=self.data)
\ No newline at end of file
