@@ -5,22 +5,23 @@ import mimetypes
 import requests
 import sys
 
+from geobox.field import Field
+
 from .base import Base
-from .utils import clean_data
+from .utils import clean_data, join_url_params
 from .task import Task
+from .vectorlayer import VectorLayer
+from .view import VectorLayerView
+from .enums import PolygonizeConnectivity, AnalysisResampleMethod, SlopeUnit, AnalysisAlgorithm, AnalysisDataType, RangeBound, DistanceUnit
 
 if TYPE_CHECKING:
     from . import GeoboxClient 
     from .user import User
+    from .aio import AsyncGeoboxClient
+    from .aio.raster import AsyncRaster
 
 class Raster(Base):
-    """
-    A class to represent a Raster in Geobox.
 
-    This class provides functionality to interact with rasters in Geobox.
-    It supports various operations including CRUD operations on rasters, as well as advanced operations like getting statistics, points, and tiles.
-    It also provides properties to access the raster data, and a method to download the raster.
-    """
     BASE_ENDPOINT: str = 'rasters/'
 
     def __init__(self,
@@ -213,7 +214,7 @@ class Raster(Base):
             >>> raster = Raster.get_raster(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> raster.delete()
         """
-        super().delete(self.endpoint)
+        super()._delete(self.endpoint)
     
 
     @property
@@ -231,8 +232,7 @@ class Raster(Base):
             >>> raster = Raster.get_raster(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> raster.thumbnail
         """
-        endpoint = urljoin(self.api.base_url, f'{self.endpoint}thumbnail/')
-        return endpoint
+        return super()._thumbnail(format='')
     
     
     @property
@@ -323,13 +323,6 @@ class Raster(Base):
         
         Raises:
             ValueError: If save_path does not end with a '/'.
-
-        Example:
-            >>> from geobox import GeoboxClient
-            >>> from geobox.file import File
-            >>> from geobox import GeoboxClient
-            >>> client = GeoboxClient()
-            >>> file_path = File.get_file(client, uuid="12345678-1234-5678-1234-567812345678")
         """
         # If save_path is provided, check if it ends with a '/'
         if save_path and save_path.endswith('/'):
@@ -511,19 +504,24 @@ class Raster(Base):
             'colormap': kwargs.get('colormap')
         })
         query_string = urlencode(params)
-        endpoint = urljoin(self.api.base_url, f'{self.endpoint}render/{z}/{x}/{y}.png')
-        endpoint = urljoin(endpoint, f'?{query_string}')
+        endpoint = f'{self.api.base_url}{self.endpoint}render/{z}/{x}/{y}.png'
+        if query_string:
+            endpoint = f'{endpoint}?{query_string}'
+
+        if not self.api.access_token and self.api.apikey:
+            endpoint = join_url_params(endpoint, {"apikey": self.api.apikey})
+            
         return endpoint
     
 
-    def get_tile_pbf_url(self, x: int, y: int, z: int, indexes: str = None) -> str:
+    def get_tile_pbf_url(self, x: int = '{x}', y: int = '{y}', z: int = '{z}', indexes: str = None) -> str:
         """
         Get the URL of the tile.
 
         Args:
-            x (int): The x coordinate of the tile.
-            y (int): The y coordinate of the tile.
-            z (int): The zoom level of the tile.
+            x (int, optional): The x coordinate of the tile.
+            y (int, optional): The y coordinate of the tile.
+            z (int, optional): The zoom level of the tile.
             indexes (str, optional): list of comma separated band indexes to be rendered. e.g. 1, 2, 3
 
         Returns:
@@ -542,17 +540,21 @@ class Raster(Base):
         query_string = urlencode(params)
         endpoint = urljoin(self.api.base_url, f'{self.endpoint}tiles/{z}/{x}/{y}.pbf')
         endpoint = urljoin(endpoint, f'?{query_string}')
+
+        if not self.api.access_token and self.api.apikey:
+            endpoint = join_url_params(endpoint, {"apikey": self.api.apikey})
+
         return endpoint
     
 
-    def get_tile_png_url(self, x: int, y: int, z: int) -> str:
+    def get_tile_png_url(self, x: int = 'x', y: int = 'y', z: int = 'z') -> str:
         """
         Get the URL of the tile.
 
         Args:
-            x (int): The x coordinate of the tile.
-            y (int): The y coordinate of the tile.
-            z (int): The zoom level of the tile.
+            x (int, optional): The x coordinate of the tile.
+            y (int, optional): The y coordinate of the tile.
+            z (int, optional): The zoom level of the tile.
 
         Returns:
             str: The URL of the tile.
@@ -564,7 +566,11 @@ class Raster(Base):
             >>> raster = Raster.get_raster(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> raster.get_tile_png_url(x=10, y=20, z=1)
         """
-        endpoint = urljoin(self.api.base_url, f'{self.endpoint}tiles/{z}/{x}/{y}.png')
+        endpoint = f'{self.api.base_url}{self.endpoint}tiles/{z}/{x}/{y}.png'
+            
+        if not self.api.access_token and self.api.apikey:
+            endpoint = f'{endpoint}?apikey={self.api.apikey}'
+
         return endpoint
 
 
@@ -606,6 +612,10 @@ class Raster(Base):
         endpoint = urljoin(self.api.base_url, f'{self.endpoint}wmts/')
         if scale:
             endpoint = f"{endpoint}?scale={scale}"
+
+        if not self.api.access_token and self.api.apikey:
+            endpoint = join_url_params(endpoint, {"apikey": self.api.apikey})
+
         return endpoint
 
 
@@ -625,6 +635,25 @@ class Raster(Base):
             >>> raster.settings
         """
         return super()._get_settings(self.endpoint)
+    
+
+    def update_settings(self, settings: Dict) -> Dict:
+        """
+        Update the settings
+
+        settings (Dict): settings dictionary
+
+        Returns:
+            Dict: updated settings
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> client = GeoboxClient()
+            >>> raster1 = client.get_raster(uuid="12345678-1234-5678-1234-567812345678")
+            >>> raster2 = client.get_raster(uuid="12345678-1234-5678-1234-567812345678")
+            >>> raster1.update_settings(raster2.settings)
+        """
+        return super()._set_settings(self.endpoint, settings)  
 
 
     def set_settings(self, **kwargs) -> None:
@@ -813,3 +842,66 @@ class Raster(Base):
             >>> raster.cache_size
         """
         return super()._cache_size(self.endpoint)
+
+
+    def to_async(self, async_client: 'AsyncGeoboxClient') -> 'AsyncRaster':
+        """
+        Switch to async version of the raster instance to have access to the async methods
+
+        Args:
+            async_client (AsyncGeoboxClient): The async version of the GeoboxClient instance for making requests.
+
+        Returns:
+            AsyncRaster: the async instance of the raster.
+
+        Example:
+            >>> from geobox import Geoboxclient
+            >>> from geobox.aio import AsyncGeoboxClient
+            >>> from geobox.raster import Raster
+            >>> client = GeoboxClient()
+            >>> raster = Raster.get_raster(client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> async with AsyncGeoboxClient() as async_client:
+            >>>     async_raster = raster.to_async(async_client)
+        """
+        from .aio.raster import AsyncRaster
+
+        return AsyncRaster(api=async_client, uuid=self.uuid, data=self.data)
+
+
+    def profile(self,
+        polyline: List,
+        number_of_samples: int = 100,
+        output_epsg: Optional[int] = None,
+        include_distance: bool = True,
+        treat_nodata_as_null: bool = True) -> Dict:
+        """
+        Create a profile form a raster along a path
+
+        Args:
+            polyline (List): Path coordinates as [x, y] pairs. Use raster CRS unless `output_epsg` is provided.
+            number_of_samples (int, optional): Number of samples along the path. default: 100.
+            output_epsg (int, optional): EPSG code for output coordinates. If None, use raster CRS.
+            include_distance (bool, optional): Include cumulative distance for each sample. default: True.
+            treat_nodata_as_null (bool, optional): Treat NoData pixels as null values. default: True.
+
+        Returns:
+            Dict: the profile result as geojson
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> client = GeoboxClient()
+            >>> raster = client.get_raster(uuid="12345678-1234-5678-1234-567812345678")
+            >>> task = raster.profile(polyline=[[0, 0], [10, 10]], number_of_samples=200)
+        """
+        endpoint = f"{self.endpoint}profile/"
+
+        data = clean_data({
+            'polyline': polyline,
+            'number_of_samples': number_of_samples,
+            'output_epsg': output_epsg,
+            'include_distance': include_distance,
+            'treat_nodata_as_null': treat_nodata_as_null
+        })
+
+        response = self.api.post(endpoint=endpoint, payload=data)
+        return response
