@@ -11,15 +11,13 @@ if TYPE_CHECKING:
     from .raster import Raster
     from .model3d import Model
     from .file import File
+    from .tile3d import Tile3d
+    from .aio import AsyncGeoboxClient
+    from .aio.task import AsyncTask
+
 
 class Task(Base):
-    """
-    A class to represent a task in Geobox.
 
-    This class provides functionality to interact with tasks in Geobox.
-    It supports various operations including getting tasks, as well as advanced operations like waiting for a task to finish.
-    It also provides properties to access the task data, and a method to abort the task.
-    """
     BASE_ENDPOINT: str = 'tasks/'
 
     def __init__(self, 
@@ -46,12 +44,12 @@ class Task(Base):
 
 
     @property
-    def output_asset(self) -> Union['VectorLayer', 'Raster', 'Model', 'File', None]:
+    def output_asset(self) -> Union['VectorLayer', 'Raster', 'Model', 'File', 'Tile3d', None]:
         """
         output asset property
 
         Returns:
-            VectorLayer | Raster | Model | None: if task type is publish, it returns the published layer
+            VectorLayer | Raster | Model | File | Tile3d | None: if task type is publish, it returns the published layer
 
         Example:
             >>> from geobox import GeoboxClient
@@ -71,6 +69,9 @@ class Task(Base):
 
         elif self.data.get('result', {}).get('file_uuid'):
             return self.api.get_file(uuid=self.data['result']['file_uuid'])
+        
+        elif self.data.get('result', {}).get('3dtiles_uuid'):
+            return self.api.get_3dtile(uuid=self.data['result']['3dtiles_uuid'])
 
         else:
             return None
@@ -188,7 +189,7 @@ class Task(Base):
                 
                 if self._is_final_state(status):
                     self._update_progress_bar(pbar, last_progress, status)
-                    return TaskStatus(status)
+                    return status
                 
                 if pbar:
                     last_progress = self._update_progress_bar(pbar, last_progress)
@@ -248,7 +249,7 @@ class Task(Base):
 
     def _check_timeout(self, start_time: float, timeout: Union[int, None]) -> None:
         """Checks if the task has exceeded the timeout period."""
-        if timeout and time.time() - start_time > timeout:
+        if timeout and time.time() - start_time > float(timeout):
             raise TimeoutError(f"Task {self.name} timed out after {timeout} seconds")
 
 
@@ -348,7 +349,6 @@ class Task(Base):
             'shared': kwargs.get('shared', False)
         }
         return super()._get_list(api, cls.BASE_ENDPOINT, params, factory_func=lambda api, item: Task(api, item['uuid'], item))
-        
 
 
     @classmethod
@@ -373,3 +373,28 @@ class Task(Base):
         """
         return super()._get_detail(api, cls.BASE_ENDPOINT, uuid, factory_func=lambda api, item: Task(api, item['uuid'], item))
 
+
+    def to_async(self, async_client: 'AsyncGeoboxClient') -> 'AsyncTask':
+        """
+        Switch to async version of the task instance to have access to the async methods
+
+        Args:
+            async_client (AsyncGeoboxClient): The async version of the GeoboxClient instance for making requests.
+
+        Returns:
+            AsyncTask: the async instance of the task.
+
+        Example:
+            >>> from geobox import Geoboxclient
+            >>> from geobox.aio import AsyncGeoboxClient
+            >>> from geobox.task import Task
+            >>> client = GeoboxClient()
+            >>> task = Task.get_task(client, uuid="12345678-1234-5678-1234-567812345678")
+            or
+            >>> task = client.get_task(uuid="12345678-1234-5678-1234-567812345678")
+            >>> async with AsyncGeoboxClient() as async_client:
+            >>>     async_task = task.to_async(async_client)
+        """
+        from .aio.task import AsyncTask
+
+        return AsyncTask(api=async_client, uuid=self.uuid, data=self.data)
\ No newline at end of file
