@@ -9,14 +9,11 @@ from .task import Task
 if TYPE_CHECKING:
     from . import GeoboxClient 
     from .user import User 
+    from .aio import AsyncGeoboxClient
+    from .aio.tileset import AsyncTileset
 
 class Tileset(Base):
-    """
-    A class to interact with tilesets in Geobox.
 
-    This class provides functionality to interact with tilesets in Geobox.
-    It supports various operations including CRUD operations on tilesets, as well as advanced operations like getting layers, and sharing tilesets.
-    """
     BASE_ENDPOINT: str = 'tilesets/'
 
     def __init__(self, 
@@ -43,7 +40,7 @@ class Tileset(Base):
         Args:
             api (GeoboxClient): The GeoboxClient instance for making requests.
             name (str): The name of the tileset.
-            layers (List['VectorLayer' | 'VectorLayerView']): list of vectorlayer and view objects to add to tileset.
+            layers (List[VectorLayer | VectorLayerView]): list of vectorlayer and view objects to add to tileset.
             display_name (str, optional): The display name of the tileset.
             description (str, optional): The description of the tileset.
             min_zoom (int, optional): The minimum zoom level of the tileset.
@@ -290,7 +287,7 @@ class Tileset(Base):
             >>> tileset = Tileset.get_tileset(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> tileset.delete()
         """
-        super().delete(urljoin(self.BASE_ENDPOINT, f'{self.uuid}/'))
+        super()._delete(urljoin(self.BASE_ENDPOINT, f'{self.uuid}/'))
     
     
     def get_layers(self, **kwargs) -> List['VectorLayer']:
@@ -526,14 +523,14 @@ class Tileset(Base):
         return self.api.post(endpoint)
 
 
-    def get_tile(self, x: int, y: int, z: int) -> str:
+    def get_tile_pbf_url(self, x: 'int' = '{x}', y: int = '{y}', z: int = '{z}') -> str:
         """
         Retrieves a tile from the tileset.
 
         Args:
-            x (int): The x coordinate of the tile.
-            y (int): The y coordinate of the tile.
-            z (int): The zoom level of the tile.
+            x (int, optional): The x coordinate of the tile.
+            y (int, optioanl): The y coordinate of the tile.
+            z (int, optional): The zoom level of the tile.
 
         Returns:
             str: The url of the tile.
@@ -545,7 +542,11 @@ class Tileset(Base):
             >>> tileset = Tileset.get_tileset(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> tileset.get_tile_tileset(x=1, y=1, z=1)
         """
-        endpoint = urljoin(self.endpoint, f'tiles/{z}/{x}/{y}.pbf') 
+        endpoint = f'{self.api.base_url}{self.endpoint}tiles/{z}/{x}/{y}.pbf'
+
+        if not self.api.access_token and self.api.apikey:
+            endpoint = f'{endpoint}?apikey={self.api.apikey}'
+
         return endpoint
 
 
@@ -561,7 +562,7 @@ class Tileset(Base):
             user_id (int, optional): The user ID.
 
         Returns:
-            List[Task]: The task object.
+            List[Task]: list of task objects.
 
         Raises:
             ValueError: If the number of workers is not one of the following: 1, 2, 4, 8, 12, 16, 20, 24.
@@ -583,14 +584,26 @@ class Tileset(Base):
         return super()._seed_cache(endpoint=self.endpoint, data=data)
 
 
-    def update_cache(self) -> List['Task']:
+    def update_cache(self, from_zoom: int, to_zoom: int, extents: List[List[float]] = None, user_id: int = 0) -> List['Task']:
         """
         Updates the cache of the tileset.
 
+        Args:
+            from_zoom (int): The starting zoom level.
+            to_zoom (int): The ending zoom level.
+            extents (List[List[float]], optional): The list of extents to update the cache for.
+            user_id (int, optional): The user ID.
+
         Returns:
-            None
+            List[Task]: list of task objects.
         """
-        return super()._update_cache(endpoint=self.endpoint)
+        data = {
+            "from_zoom": from_zoom,
+            "to_zoom": to_zoom,
+            "extents": extents,
+            "user_id": user_id
+        }
+        return super()._update_cache(endpoint=self.endpoint, data=data)
 
 
     @property
@@ -619,3 +632,27 @@ class Tileset(Base):
             >>> tileset.clear_cache()
         """
         super()._clear_cache(endpoint=self.endpoint)
+
+
+    def to_async(self, async_client: 'AsyncGeoboxClient') -> 'AsyncTileset':
+        """
+        Switch to async version of the tileset instance to have access to the async methods
+
+        Args:
+            async_client (AsyncGeoboxClient): The async version of the GeoboxClient instance for making requests.
+
+        Returns:
+            AsyncTileset: the async instance of the tileset.
+
+        Example:
+            >>> from geobox import Geoboxclient
+            >>> from geobox.aio import AsyncGeoboxClient
+            >>> from geobox.tileset import Tileset
+            >>> client = GeoboxClient()
+            >>> tileset = Tileset.get_tileset(client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> async with AsyncGeoboxClient() as async_client:
+            >>>     async_tileset = tileset.to_async(async_client)
+        """
+        from .aio.tileset import AsyncTileset
+
+        return AsyncTileset(api=async_client, uuid=self.uuid, data=self.data)
\ No newline at end of file
