@@ -8,6 +8,9 @@ from .plan import Plan
 
 if TYPE_CHECKING:
     from . import GeoboxClient
+    from .aio import AsyncGeoboxClient
+    from .aio.user import AsyncUser
+    from .aio.user import AsyncSession
 
 
 class User(Base):
@@ -270,7 +273,7 @@ class User(Base):
             >>> from geobox.user import User
             >>> client = GeoboxClient()
             >>> user = User.get_user(client, user_id=1)
-            >>> user.update_user(status=UserStatus.PENDING)
+            >>> user.update(status=UserStatus.PENDING)
         """
         data = {
             "username": kwargs.get('username'),
@@ -316,7 +319,7 @@ class User(Base):
             >>> user = User.get_user(client, user_id=1)
             >>> user.delete()
         """
-        super().delete(self.endpoint)
+        super()._delete(self.endpoint)
 
     
     def get_sessions(self, user_id: int = 'me') -> List['Session']:
@@ -337,9 +340,9 @@ class User(Base):
             or
             >>> user = client.get_user(user_id=1)
 
-            >>> user.get_user_sessions()       
+            >>> user.get_sessions()       
             or
-            >>> client.get_user_sessions()
+            >>> client.get_sessions()
         """
         params = clean_data({
             'f': 'json'
@@ -370,7 +373,7 @@ class User(Base):
             >>> from geobox import GeoboxClient
             >>> from geobox.user import User
             >>> client = GeoboxClient()
-            >>> user = client.get_user()
+            >>> user = client.get_user(user_id=1)
             >>> user.change_password(new_password='user_new_password')
         """
         data = clean_data({
@@ -382,7 +385,7 @@ class User(Base):
 
     def renew_plan(self) -> None:
         """
-        Renew the user plan
+        Renew the user plan (privileges required)
 
         Returns:
             None
@@ -396,6 +399,31 @@ class User(Base):
         self.api.post(endpoint)
 
 
+    def to_async(self, async_client: 'AsyncGeoboxClient') -> 'AsyncUser':
+        """
+        Switch to async version of the user instance to have access to the async methods
+
+        Args:
+            async_client (AsyncGeoboxClient): The async version of the GeoboxClient instance for making requests.
+
+        Returns:
+            AsyncUser: the async instance of the user.
+
+        Example:
+            >>> from geobox import Geoboxclient
+            >>> from geobox.aio import AsyncGeoboxClient
+            >>> from geobox.user import User
+            >>> client = GeoboxClient()
+            >>> user = User.get_user(client) # without user_id parameter, it gets the current user
+            or
+            >>> user = client.get_user() # without user_id parameter, it gets the current user
+            >>> async with AsyncGeoboxClient() as async_client:
+            >>>     async_user = user.to_async(async_client)
+        """
+        from .aio.user import AsyncUser
+
+        return AsyncUser(api=async_client, user_id=self.user_id, data=self.data)
+
 
 
 class Session(Base):
@@ -445,4 +473,32 @@ class Session(Base):
             'user_id': self.user.user_id,
             'session_uuid': self.uuid
         })
-        self.user.api.post(self.endpoint, data)
\ No newline at end of file
+        self.user.api.post(self.endpoint, data)
+
+
+    def to_async(self, async_client: 'AsyncGeoboxClient') -> 'AsyncSession':
+        """
+        Switch to async version of the session instance to have access to the async methods
+
+        Args:
+            async_client (AsyncGeoboxClient): The async version of the GeoboxClient instance for making requests.
+
+        Returns:
+            AsyncSession: the async instance of the session.
+
+        Example:
+            >>> from geobox import Geoboxclient
+            >>> from geobox.aio import AsyncGeoboxClient
+            >>> from geobox.user import User
+            >>> client = GeoboxClient()
+            >>> user = User.get_user(client) # without user_id parameter, it gets the current user
+            or
+            >>> user = client.get_user() # without user_id parameter, it gets the current user
+            >>> session = user.get_sessions()[0]
+            >>> async with AsyncGeoboxClient() as async_client:
+            >>>     async_session = session.to_async(async_client)
+        """
+        from .aio.user import AsyncSession
+        
+        async_user = self.user.to_async(async_client=async_client)
+        return AsyncSession(uuid=self.uuid, data=self.data, user=async_user)
\ No newline at end of file
