@@ -8,15 +8,18 @@ from .field import Field, FieldType
 from .feature import Feature
 from .enums import LayerType
 from .task import Task
-from .enums import InputGeomType, FileOutputFormat
+from .enums import InputGeomType, FileOutputFormat, AnalysisDataType
 from .version import VectorLayerVersion
 
-
 if TYPE_CHECKING:
     from .api import GeoboxClient
     from .view import VectorLayerView
     from .user import User
     from .file import File
+    from .attachment import Attachment
+    from .aio import AsyncGeoboxClient
+    from .aio.vectorlayer import AsyncVectorLayer
+
 
 class VectorLayer(Base):
     """
@@ -330,12 +333,22 @@ class VectorLayer(Base):
             >>> layer = VectorLayer.get_vector(api=client, uuid="12345678-1234-5678-1234-567812345678")
             >>> layer.delete()
         """
-        super().delete(endpoint=self.endpoint)
+        super()._delete(endpoint=self.endpoint)
 
 
     def make_permanent(self) -> None:
         """
         Make the layer permanent.
+
+        Returns:
+            None
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> from geobox.vectorlayer import VectorLayer
+            >>> client = GeoboxClient()
+            >>> layer = VectorLayer.get_vector(api=client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> layer.make_permanent()
         """
         endpoint = urljoin(self.endpoint, 'makePermanent/')
         response = self.api.post(endpoint, is_json=False)
@@ -542,7 +555,7 @@ class VectorLayer(Base):
         Get a specific field by its name.
         
         Args:
-            name (str, optional): The name of the field to retrieve.
+            name (str): The name of the field to retrieve.
 
         Returns:
             Field: The requested field instance.
@@ -1000,17 +1013,17 @@ class VectorLayer(Base):
                             factory_func=lambda api, item: VectorLayerView(api, item['uuid'], self.layer_type, item))
 
 
-    def get_tile(self, x: int, y: int, z: int) -> str:
+    def get_tile_pbf_url(self, x: int = '{x}', y: int = '{y}', z: int = '{z}') -> str:
         """
-        Get a vector tile for the layer.
+        Get a vector tile pbf url for the layer.
         
         Args:
-            x (int): X coordinate of the tile.
-            y (int): Y coordinate of the tile.
-            z (int): Zoom level of the tile.
+            x (int, optional): X coordinate of the tile.
+            y (int, optional): Y coordinate of the tile.
+            z (int, optioanl): Zoom level of the tile.
 
         Returns:
-            str: The vector tile data.
+            str: The vector tile url.
 
         Example:
             >>> from geobox import GeoboxClient
@@ -1019,7 +1032,11 @@ class VectorLayer(Base):
             >>> layer = VectorLayer.get_vector(api=client, uuid="12345678-1234-5678-1234-567812345678")
             >>> tile = layer.get_tile(x=10, y=20, z=1)
         """
-        endpoint = f'{self.BASE_ENDPOINT}{self.endpoint}tiles/{z}/{x}/{y}.pbf'
+        endpoint = f'{self.api.base_url}{self.endpoint}tiles/{z}/{x}/{y}.pbf'
+
+        if not self.api.access_token and self.api.apikey:
+            endpoint = f'{endpoint}?apikey={self.api.apikey}'
+
         return endpoint
 
 
@@ -1057,6 +1074,25 @@ class VectorLayer(Base):
             >>> setting = layer.setting
         """
         return super()._get_settings(endpoint=self.endpoint)
+    
+
+    def update_settings(self, settings: Dict) -> Dict:
+        """
+        Update the settings
+
+        settings (Dict): settings dictionary
+
+        Returns:
+            Dict: updated settings
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> client = GeoboxClient()
+            >>> layer1 = client.get_vector(uuid="12345678-1234-5678-1234-567812345678")
+            >>> layer2 = client.get_vector(uuid="12345678-1234-5678-1234-567812345678")
+            >>> layer1.update_settings(layer2.settings)
+        """
+        return super()._set_settings(self.endpoint, settings)  
 
 
     def set_settings(self, **kwargs) -> Dict:
@@ -1223,4 +1259,105 @@ class VectorLayer(Base):
             >>> layer.prune_edited_areas()
         """
         endpoint = urljoin(self.endpoint, 'prune/')
-        return self.api.post(endpoint)
\ No newline at end of file
+        return self.api.post(endpoint)
+    
+
+    def get_attachments(self, **kwargs) -> List['Attachment']:
+        """
+        Get the resouces attachments
+
+        Keyword Args:
+            element_id (str): the id of the element with attachment.
+            search (str): search term for keyword-based searching among all textual fields.
+            order_by (str): comma separated list of fields for sorting results [field1 A|D, field2 A|D, …]. e.g. name A, type D. NOTE: "A" denotes ascending order and "D" denotes descending order.
+            skip (int): Number of items to skip. default is 0.
+            limit (int): Number of items to return. default is 10.
+            return_count (bool): Whether to return total count. default is False.
+
+        Returns:
+            List[Attachment] | int: A list of attachments instances or the total number of attachments.
+
+        Raises:
+            TypeError: if the resource type is not supported
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> from geobox.vectorlayer import VectorLayer
+            >>> client = GeoboxClient()
+            >>> layer = VectorLayer.get_vector(api=client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> layer.get_attachments()
+        """
+        from .attachment import Attachment
+
+        return Attachment.get_attachments(self.api, resource=self, **kwargs)
+    
+    
+    def create_attachment(self, 
+                            name: str, 
+                            loc_x: int,
+                            loc_y: int,
+                            file: 'File',
+                            feature: 'Feature' = None,
+                            display_name: str = None, 
+                            description: str = None) -> 'Attachment':
+        """
+        Create a new Attachment.
+
+        Args:
+            name (str): The name of the scene.
+            loc_x (int): x parameter of the attachment location.
+            loc_y (int): y parameter of the attachment location.
+            file (File): the file object.
+            feature (Feature, optional): the feature object.
+            display_name (str, optional): The display name of the scene.
+            description (str, optional): The description of the scene.
+
+        Returns:
+            Attachment: The newly created Attachment instance.
+
+        Raises:
+            ValidationError: If the Attachment data is invalid.
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> from geobox.vectorlayer import VectorLayer
+            >>> client = GeoboxClient()
+            >>> layer = VectorLayer.get_vector(api=client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> file = client.get_file(uuid="12345678-1234-5678-1234-567812345678")
+            >>> layer.create_attachment(name='test', loc_x=10, loc_y=10, file=file)
+        """
+        from .attachment import Attachment
+
+        return Attachment.create_attachment(self.api,
+                                            name=name,
+                                            loc_x=loc_x,
+                                            loc_y=loc_y,
+                                            resource=self,
+                                            file=file,
+                                            feature=feature,
+                                            display_name=display_name,
+                                            description=description)
+    
+
+    def to_async(self, async_client: 'AsyncGeoboxClient') -> 'AsyncVectorLayer':
+        """
+        Switch to async version of the vector layer instance to have access to the async methods
+
+        Args:
+            async_client (AsyncGeoboxClient): The async version of the GeoboxClient instance for making requests.
+
+        Returns:
+            AsyncVectorLayer: the async instance of the vector layer.
+
+        Example:
+            >>> from geobox import Geoboxclient
+            >>> from geobox.aio import AsyncGeoboxClient
+            >>> from geobox.vectorlayer import VectorLayer
+            >>> client = GeoboxClient()
+            >>> layer = VectorLayer.get_vector(client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> async with AsyncGeoboxClient() as async_client:
+            >>>     async_layer = layer.to_async(async_client)
+        """
+        from .aio.vectorlayer import AsyncVectorLayer
+
+        return AsyncVectorLayer(api=async_client, uuid=self.uuid, layer_type=self.layer_type, data=self.data)
\ No newline at end of file
