@@ -7,19 +7,16 @@ if TYPE_CHECKING:
     from . import GeoboxClient
     from .field import Field
     from .user import User
-    from .enums import InputGeomType, FieldType
+    from .enums import InputGeomType
     from .task import Task
     from .file import File
+    from .attachment import Attachment
+    from .aio import AsyncGeoboxClient
+    from .aio.view import AsyncVectorLayerView
 
 
 class VectorLayerView(VectorLayer):
-    """
-    A class representing a vector layer view in Geobox.
 
-    This class provides functionality to create, manage, and manipulate vector layer views.
-    It supports various operations including CRUD operations on views, as well as advanced operations like getting fields, features, and sharing views.
-    It also provides properties to access the view data, and a method to update the view.
-    """
     BASE_ENDPOINT = 'vectorLayerViews/'
 
     def __init__(self, 
@@ -76,15 +73,15 @@ class VectorLayerView(VectorLayer):
             api (GeoboxClient): The GeoboxClient instance for making requests.
 
         Keyword Args:
-            layer_id(int): The id of the layer.
+            layer_id(int): The id of the source vector layer.
             include_settings(bool): Whether to include the settings of the layer. default is False.
             q(str): query filter based on OGC CQL standard. e.g. "field1 LIKE '%GIS%' AND created_at > '2021-01-01'"
             search(str): search term for keyword-based searching among search_fields or all textual fields if search_fields does not have value. NOTE: if q param is defined this param will be ignored.
             search_fields(str): Comma separated list of fields for searching.
             order_by(str): comma separated list of fields for sorting results [field1 A|D, field2 A|D, …]. e.g. name A, type D. NOTE: "A" denotes ascending order and "D" denotes descending order.
             return_count(bool): Whether to return the count of the layer views. default is False.
-            skip(int): The number of layer views to skip. minimum is 0.
-            limit(int): The maximum number of layer views to return. minimum is 1. default is 10.
+            skip(int): The number of views to skip. minimum is 0.
+            limit(int): The maximum number of views to return. minimum is 1. default is 10.
             user_id(int): Specific user. privileges required.
             shared(bool): Whether to return shared views. default is False.
 
@@ -249,9 +246,9 @@ class VectorLayerView(VectorLayer):
             >>> from geobox.view import VectorLayerView
             >>> client = GeoboxClient()
             >>> view = VectorLayerView.get_view(client, uuid="12345678-1234-5678-1234-567812345678")
-            >>> view.update_view(name="new_name")
-            >>> view.update_view(display_name="new_display_name")
-            >>> view.update_view(description="new_description")
+            >>> view.update(name="new_name")
+            >>> view.update(display_name="new_display_name")
+            >>> view.update(description="new_description")
         """
         return super().update(name=kwargs.get('name'), display_name=kwargs.get('display_name'), description=kwargs.get('description'))
     
@@ -270,7 +267,7 @@ class VectorLayerView(VectorLayer):
             >>> view = VectorLayerView.get_view(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> view.delete()
         """        
-        return super().delete()
+        return super()._delete(self.endpoint)
 
 
     def share(self, users: List['User']) -> None:
@@ -506,7 +503,8 @@ class VectorLayerView(VectorLayer):
             NotFoundError: If the feature with the specified ID is not found.
 
         Example:
-            >>> from geobox import GeoboxClient, VectorLayerView
+            >>> from geobox import GeoboxClient
+            >>> from geobox.view import VectorLayerView
             >>> client = GeoboxClient()
             >>> view = VectorLayerView.get_view(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> feature = view.get_feature(id=1)
@@ -663,9 +661,9 @@ class VectorLayerView(VectorLayer):
                                        bbox, out_srid, zipped, feature_ids, bbox_srid, q, fields)
 
     
-    def get_tile(self, x: int, y: int, z: int) -> Dict:
+    def get_tile_pbf_url(self, x: int = '{x}', y: int = '{y}', z: int = '{z}') -> str:
         """
-        Get a vector tile for the layer.
+        Get a vector tile pbf url for the view.
         
         Args:
             x (int): X coordinate of the tile.
@@ -673,7 +671,7 @@ class VectorLayerView(VectorLayer):
             z (int): Zoom level of the tile.
 
         Returns:
-            Dict: The vector tile data.
+            str: the vector tile url.
 
         Example:
             >>> from geobox import GeoboxClient
@@ -682,7 +680,7 @@ class VectorLayerView(VectorLayer):
             >>> view = VectorLayerView.get_view(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> tile = view.get_tile(x=10, y=20, z=1)
         """
-        return super().get_tile(x, y, z)
+        return super().get_tile_pbf_url(x, y, z)
     
 
     def get_tile_json(self) -> Dict:
@@ -720,6 +718,25 @@ class VectorLayerView(VectorLayer):
         return super().settings
 
 
+    def update_settings(self, settings: Dict) -> Dict:
+        """
+        Update the settings
+
+        settings (Dict): settings dictionary
+
+        Returns:
+            Dict: updated settings
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> client = GeoboxClient()
+            >>> view1 = client.get_view(uuid="12345678-1234-5678-1234-567812345678")
+            >>> view2 = client.get_view(uuid="12345678-1234-5678-1234-567812345678")
+            >>> view1.update_settings(view2.settings)
+        """
+        return super().update_settings(settings) 
+
+
     def set_settings(self, **kwargs) -> Dict:
         """
         Set the settings of the Vector Layer.
@@ -862,3 +879,104 @@ class VectorLayerView(VectorLayer):
             >>> view.prune_edited_areas()
         """
         return super().prune_edited_areas()
+
+
+    def get_attachments(self, **kwargs) -> List['Attachment']:
+        """
+        Get the resouces attachments
+
+        Keyword Args:
+            element_id (str): the id of the element with attachment.
+            search (str): search term for keyword-based searching among all textual fields.
+            order_by (str): comma separated list of fields for sorting results [field1 A|D, field2 A|D, …]. e.g. name A, type D. NOTE: "A" denotes ascending order and "D" denotes descending order.
+            skip (int): Number of items to skip. default is 0.
+            limit (int): Number of items to return. default is 10.
+            return_count (bool): Whether to return total count. default is False.
+
+        Returns:
+            List[Attachment] | int: A list of attachments instances or the total number of attachments.
+
+        Raises:
+            TypeError: if the resource type is not supported
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> from geobox.view import VectorLayerView
+            >>> client = GeoboxClient()
+            >>> view = VectorLayerView.get_view(client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> view.get_attachments()
+        """
+        from .attachment import Attachment
+
+        return Attachment.get_attachments(self.api, resource=self, **kwargs)
+    
+    
+    def create_attachment(self, 
+                            name: str, 
+                            loc_x: int,
+                            loc_y: int,
+                            file: 'File',
+                            feature: 'Feature' = None,
+                            display_name: str = None, 
+                            description: str = None) -> 'Attachment':
+        """
+        Create a new Attachment.
+
+        Args:
+            name (str): The name of the scene.
+            loc_x (int): x parameter of the attachment location.
+            loc_y (int): y parameter of the attachment location.
+            file (File): the file object.
+            feature (Feature, optional): the feature object.
+            display_name (str, optional): The display name of the scene.
+            description (str, optional): The description of the scene.
+
+        Returns:
+            Attachment: The newly created Attachment instance.
+
+        Raises:
+            ValidationError: If the Attachment data is invalid.
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> from geobox.view import VectorLayerView
+            >>> client = GeoboxClient()
+            >>> view = VectorLayerView.get_view(client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> file = client.get_files()[0]
+            >>> view.create_attachment(name='test', loc_x=10, loc_y=10, file=file)
+        """
+        from .attachment import Attachment
+
+        return Attachment.create_attachment(self.api,
+                                            name=name,
+                                            loc_x=loc_x,
+                                            loc_y=loc_y,
+                                            resource=self,
+                                            file=file,
+                                            feature=feature,
+                                            display_name=display_name,
+                                            description=description)
+    
+
+    def to_async(self, async_client: 'AsyncGeoboxClient') -> 'AsyncVectorLayerView':
+        """
+        Switch to async version of the view instance to have access to the async methods
+
+        Args:
+            async_client (AsyncGeoboxClient): The async version of the GeoboxClient instance for making requests.
+
+        Returns:
+            AsyncVectorLayerView: the async instance of the view.
+
+        Example:
+            >>> from geobox import Geoboxclient
+            >>> from geobox.aio import AsyncGeoboxClient
+            >>> from geobox.view import VectorLayerView
+            >>> client = GeoboxClient()
+            >>> view = VectorLayerView.get_view(client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> async with AsyncGeoboxClient() as async_client:
+            >>>     async_view = view.to_async(async_client)
+        """
+        from .aio.view import AsyncVectorLayerView
+
+        return AsyncVectorLayerView(api=async_client, uuid=self.uuid, layer_type=self.layer_type, data=self.data)
\ No newline at end of file
