@@ -6,6 +6,8 @@ import tempfile
 from geobox.api import *
 from geobox.exception import AuthenticationError
 from geobox.enums import RoutingGeometryType, RoutingOverviewLevel, UsageParam, UsageScale
+from geobox.raster_analysis import RasterAnalysis
+from geobox.vector_tool import VectorTool
 
 
 def test_init_with_apikey(env_vars):
@@ -635,6 +637,28 @@ def test_init_calls_update_access_token_always_triggers(env_vars):
         mock_update.assert_called_once_with('test_token')
 
 
+def test_raster_analysis():
+    with patch('geobox.api.GeoboxClient.get_access_token') as mock_get_token, \
+         patch('geobox.api.GeoboxClient.get') as mock_get:
+        
+        mock_get_token.return_value = 'test_token'
+        
+        client = GeoboxClient(username='testuser', password='testpassword')
+        assert type(client.raster_analysis) == RasterAnalysis
+        assert client.raster_analysis.api == client
+
+
+def test_vector_tool():
+    with patch('geobox.api.GeoboxClient.get_access_token') as mock_get_token, \
+         patch('geobox.api.GeoboxClient.get') as mock_get:
+        
+        mock_get_token.return_value = 'test_token'
+        
+        client = GeoboxClient(username='testuser', password='testpassword')
+        assert type(client.vector_tool) == VectorTool
+        assert client.vector_tool.api == client
+
+
 def test_get_vectors(mock_vector_data):
     with patch('geobox.api.GeoboxClient.get_access_token') as mock_get_token, \
          patch('geobox.api.GeoboxClient.get') as mock_get:
@@ -1437,6 +1461,67 @@ def test_get_version_by_name(mock_version_data):
         assert version.data == mock_version_data
 
 
+def test_get_layouts(mock_layout_data):
+    with patch('geobox.api.GeoboxClient.get_access_token') as mock_get_token, \
+         patch('geobox.api.GeoboxClient.get') as mock_get:
+        
+        mock_get_token.return_value = 'test_token'
+        mock_get.return_value = [mock_layout_data, mock_layout_data]
+        
+        client = GeoboxClient(username='testuser', password='testpassword')
+        layouts = client.get_layouts()
+        
+        assert len(layouts) == 2
+        assert isinstance(layouts[0], Layout)
+        assert layouts[0].data == mock_layout_data
+
+
+def test_create_layout(mock_layout_data):
+    with patch('geobox.api.GeoboxClient.get_access_token') as mock_get_token, \
+         patch('geobox.api.GeoboxClient.post') as mock_get:
+        
+        mock_get_token.return_value = 'test_token'
+        mock_get.return_value = mock_layout_data
+        
+        client = GeoboxClient(username='testuser', password='testpassword')
+        layout = client.create_layout(name=mock_layout_data['name'],
+                                        display_name=mock_layout_data['display_name'],
+                                        description=mock_layout_data['description'],
+                                        settings=mock_layout_data['settings'],
+                                        thumbnail=mock_layout_data.get('thumbnail'))
+        
+        assert isinstance(layout, Layout)
+        assert layout.data == mock_layout_data
+
+
+def test_get_layout(mock_layout_data):
+    with patch('geobox.api.GeoboxClient.get_access_token') as mock_get_token, \
+         patch('geobox.api.GeoboxClient.get') as mock_get:
+        
+        mock_get_token.return_value = 'test_token'
+        mock_get.return_value = mock_layout_data
+        
+        client = GeoboxClient(username='testuser', password='testpassword')
+        layout = client.get_layout(uuid=mock_layout_data['uuid'])
+        
+        assert isinstance(layout, Layout)
+        assert layout.data == mock_layout_data
+
+
+def test_get_layout_by_name(mock_layout_data):
+    with patch('geobox.api.GeoboxClient.get_access_token') as mock_get_token, \
+         patch('geobox.api.GeoboxClient.get') as mock_get:
+        
+        mock_get_token.return_value = 'test_token'
+        mock_get.return_value = [mock_layout_data]
+        
+        client = GeoboxClient(username='testuser', password='testpassword')
+        layout = client.get_layout_by_name(name=mock_layout_data['name'])
+        
+        assert isinstance(layout, Layout)
+        assert layout.data == mock_layout_data
+
+
 def test_get_3dtiles(mock_tile3d_data):
     with patch('geobox.api.GeoboxClient.get_access_token') as mock_get_token, \
          patch('geobox.api.GeoboxClient.get') as mock_get:
@@ -1626,6 +1711,20 @@ def test_get_plan(mock_plan_data):
         assert plan.data == mock_plan_data
 
 
+def test_get_plan_by_name(mock_plan_data):
+    with patch('geobox.api.GeoboxClient.get_access_token') as mock_get_token, \
+         patch('geobox.api.GeoboxClient.get') as mock_get:
+        
+        mock_get_token.return_value = 'test_token'
+        mock_get.return_value = [mock_plan_data]
+        
+        client = GeoboxClient(username='testuser', password='testpassword')
+        plan = client.get_plan_by_name(name=mock_plan_data['name'])
+        
+        assert isinstance(plan, Plan)
+        assert plan.data == mock_plan_data
+
+
 def test_get_dashboards(mock_dashboard_data):
     with patch('geobox.api.GeoboxClient.get_access_token') as mock_get_token, \
          patch('geobox.api.GeoboxClient.get') as mock_get:
@@ -1737,7 +1836,7 @@ def test_get_attachments(mock_attachment_data, mock_vector_data):
         
         client = GeoboxClient(username='testuser', password='testpassword')
         layer = VectorLayer(client, mock_vector_data['uuid'], LayerType.Polygon, mock_vector_data)
-        attachments = client.get_attachments(resource_type=AttachmentResourceType.Vector, resource_uuid=layer.uuid)
+        attachments = client.get_attachments(resource=layer)
         
         assert len(attachments) == 2
         assert isinstance(attachments[0], Attachment)
@@ -1947,4 +2046,4 @@ def test_update_usage():
         client = GeoboxClient(username='testuser', password='testpassword')
         update = client.update_usage()
 
-        assert update == data
\ No newline at end of file
+        assert update == data
