@@ -69,7 +69,7 @@ def test_save(api, mock_vector_data, mock_feature_data, feature_type):
     request_data = feature_data.copy()
     
     feature = Feature(layer, srid=3857, data=request_data.copy())
-    api.post.return_value = feature_data
+    api.put.return_value = feature_data
 
     feature.save()
     api.put.assert_called_once_with(f'{layer.endpoint}features/{feature_data["id"]}/', request_data)
@@ -441,4 +441,11 @@ def test_get_count_error(api, mock_vector_data, mock_feature_data):
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType('Point'), data=mock_vector_data)
     api.get.return_value = {'count_number': 123}
     with pytest.raises(ValueError, match='Invalid response format'):
-        count = layer.get_features(return_count=True)
\ No newline at end of file
+        count = layer.get_features(return_count=True)
+
+
+def test_to_async(api, async_api, mock_vector_data, mock_feature_data):
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType('Point'), data=mock_vector_data)
+    feature = Feature(layer, srid=3857, data=mock_feature_data['Point'])
+    async_instance = feature.to_async(async_api)
+    assert async_instance.api == async_api  
\ No newline at end of file
