@@ -2,6 +2,7 @@ import pytest
 from unittest.mock import patch
 
 from geobox.log import Log
+from geobox.user import User
 
 def test_init(api, mock_log_data):
     log = Log(api, mock_log_data['id'], mock_log_data)
@@ -32,3 +33,15 @@ def test_delete(api, mock_log_data):
     assert log.log_id is None
     assert log.endpoint is None
 
+
+def test_user_property(api, mock_log_data, mock_user_data):
+    log = Log(api, mock_log_data['id'], mock_log_data)
+    api.get_user.return_value = User(api, mock_user_data['1']['id'], mock_user_data['1'])
+    user = log.user
+    assert user.data == mock_user_data['1']
+
+
+def test_to_async(api, async_api, mock_log_data):
+    log = Log(api, mock_log_data['id'], mock_log_data)
+    async_instance = log.to_async(async_api)
+    assert async_instance.api == async_api 
\ No newline at end of file
