@@ -7,6 +7,8 @@ from geobox.map import Map
 from geobox.model3d import Model
 from geobox.user import User
 from geobox.task import Task
+from geobox.attachment import Attachment
+from geobox.file import File
 
 
 def test_init(api, mock_map_data):
@@ -154,9 +156,15 @@ def test_style(api, mock_map_data):
 
 
 def test_thumbnail(api, mock_map_data):
+    api.access_token = ''
+    api.apikey = 'apikey_1234'
     map = Map(api, uuid=mock_map_data['uuid'], data=mock_map_data)
     thumbnail_url = map.thumbnail
-    assert thumbnail_url == f'{api.base_url}{map.endpoint}thumbnail.png'
+    assert thumbnail_url == f'{api.base_url}{map.endpoint}thumbnail.png?apikey=apikey_1234'
+    # error
+    api.apikey = ''
+    with pytest.raises(ValueError):
+        map.thumbnail
 
 
 def test_set_readonly(api, mock_map_data):
@@ -183,6 +191,11 @@ def test_wmts(api, mock_map_data):
     map = Map(api, uuid=mock_map_data['uuid'], data=mock_map_data)
     wmts_url = map.wmts(scale=1)
     assert wmts_url == f'{api.base_url}{map.endpoint}wmts/?scale=1'
+    # apikey
+    api.access_token = ''
+    api.apikey = 'apikey_1234'
+    wmts_url = map.wmts(scale=1)
+    assert wmts_url == f"{api.base_url}{map.endpoint}wmts/?scale=1&apikey=apikey_1234"
 
 
 def test_share(api, mock_map_data, mock_user_data):
@@ -289,6 +302,15 @@ def test_settings(api, mock_map_data):
     assert settings == mock_map_data['settings']
 
 
+def test_update_settings(api, mock_map_data):
+    map1 = Map(api, uuid=mock_map_data['uuid'], data=mock_map_data)
+    map2 = Map(api, uuid=mock_map_data['uuid'], data=mock_map_data)
+    settings = map2.settings
+    api.put.return_value = settings
+    map1.update_settings(map2.settings)
+    api.put.assert_called_once_with(f'{map1.endpoint}settings/', settings)
+
+
 def test_set_settings(api, mock_map_data):
     map = Map(api, uuid=mock_map_data['uuid'], data=mock_map_data)
     settings = map.settings
@@ -541,5 +563,51 @@ def test_add_model_with_existing_models(api, mock_map_data, mock_model_data, moc
 def test_image_tile_url(api, mock_map_data):
     map = Map(api, uuid=mock_map_data['uuid'], data=mock_map_data)
 
-    assert map.image_tile_url() == f"{map.BASE_ENDPOINT}{map.endpoint}"+"{z}/{x}/{y}.png"
-    assert map.image_tile_url(x=1, y=2, z=3, format='.pbf') == f"{map.BASE_ENDPOINT}{map.endpoint}3/1/2.pbf"
\ No newline at end of file
+    assert map.image_tile_url() == f"{map.api.base_url}{map.endpoint}tiles/"+"{z}/{x}/{y}.png"
+    assert map.image_tile_url(x=1, y=2, z=3, format='.pbf') == f"{map.api.base_url}{map.endpoint}tiles/3/1/2.pbf"
+
+    # apikey
+    api.access_token = ''
+    api.apikey = 'apikey@1234'
+
+    assert map.image_tile_url() == f"{map.api.base_url}{map.endpoint}tiles/"+"{z}/{x}/{y}.png?apikey=apikey@1234"
+
+
+def test_export_map_to_image(api, mock_map_data, mock_success_task_data):
+    map = Map(api, uuid=mock_map_data['uuid'], data=mock_map_data)
+
+    api.post.return_value = {
+        'task_id': mock_success_task_data['uuid']
+    }
+    api.get_task.return_value = Task(api, mock_success_task_data['uuid'], mock_success_task_data)
+
+    task = map.export_map_to_image(bbox=[50.275, 35.1195, 51.4459, 36.0416], width=100, height=100)
+    
+    api.post.assert_called_once_with('maps/da9a505b-7b51-4042-a3ba-c821e4f2cd34/export/?uuid=da9a505b-7b51-4042-a3ba-c821e4f2cd34&bbox=%5B50.275%2C+35.1195%2C+51.4459%2C+36.0416%5D&width=100&height=100')
+    assert type(task) == Task
+
+
+def test_get_attachments(api, mock_map_data, mock_attachment_data):
+    map = Map(api, uuid=mock_map_data['uuid'], data=mock_map_data)
+
+    api.get.return_value = [mock_attachment_data, mock_attachment_data, mock_attachment_data]
+
+    attachments = map.get_attachments()
+    assert len(attachments) == 3
+    assert type(attachments[0]) == Attachment
+
+
+def test_create_attachment(api, mock_map_data, mock_attachment_data, mock_file_data):
+    map = Map(api, uuid=mock_map_data['uuid'], data=mock_map_data)
+    file = File(api, uuid=mock_file_data['uuid'], data=mock_file_data)
+
+    api.post.return_value = mock_attachment_data
+    attachment = map.create_attachment(name='test', loc_x=10, loc_y=10, file=file)
+    assert type(attachment) == Attachment
+    assert attachment.data == mock_attachment_data
+
+
+def test_to_async(api, async_api, mock_map_data):
+    map = Map(api, uuid=mock_map_data['uuid'], data=mock_map_data)
+    async_instance = map.to_async(async_api)
+    assert async_instance.api == async_api 
\ No newline at end of file
