@@ -125,7 +125,7 @@ def test_thumbnail(api, mock_mosaic_data):
     
     thumbnail = mosaic.thumbnail
     
-    assert thumbnail == f"{api.base_url}{mosaic.endpoint}thumbnail/"
+    assert thumbnail == f"{api.base_url}{mosaic.endpoint}thumbnail"
 
 
 def test_get_point(api, mock_mosaic_data):
@@ -184,6 +184,15 @@ def test_settings(api, mock_mosaic_data):
     assert settings == {'value': 'test'}
 
 
+def test_update_settings(api, mock_mosaic_data):
+    mosaic1 = Mosaic(api, uuid=mock_mosaic_data['uuid'], data=mock_mosaic_data)
+    mosaic2 = Mosaic(api, uuid=mock_mosaic_data['uuid'], data=mock_mosaic_data)
+    settings = mosaic2.settings
+    api.put.return_value = settings
+    mosaic1.update_settings(mosaic2.settings)
+    api.put.assert_called_once_with(f'{mosaic1.endpoint}settings/', settings)
+
+
 def test_set_settings(api, mock_mosaic_data):
     """Test the set_settings method."""
     mosaic = Mosaic(api, mock_mosaic_data['uuid'], mock_mosaic_data)
@@ -388,4 +397,10 @@ def test_cache_size(api, mock_mosaic_data):
     api.post.return_value = 1024
     size = mosaic.cache_size
     assert size == 1024
-    api.post.assert_called_once_with(f'{mosaic.endpoint}cache/size/')
\ No newline at end of file
+    api.post.assert_called_once_with(f'{mosaic.endpoint}cache/size/')
+
+
+def test_to_async(api, async_api, mock_mosaic_data):
+    mosaic = Mosaic(api, mock_mosaic_data['uuid'], mock_mosaic_data)
+    async_instance = mosaic.to_async(async_api)
+    assert async_instance.api == async_api 
\ No newline at end of file
