@@ -5,9 +5,11 @@ import os
 import tempfile
 from urllib.parse import urljoin
 
+from geobox.enums import LayerType
 from geobox.raster import Raster
 from geobox.user import User
 from geobox.task import Task
+from geobox.vectorlayer import VectorLayer
 
 
 def test_init(api, mock_raster_data):
@@ -119,7 +121,7 @@ def test_thumbnail(api, mock_raster_data):
     """Test getting raster thumbnail URL."""
     raster = Raster(api, uuid=mock_raster_data['uuid'], data=mock_raster_data)
     thumbnail_url = raster.thumbnail
-    assert thumbnail_url == f"{api.base_url}{raster.endpoint}thumbnail/"
+    assert thumbnail_url == f"{api.base_url}{raster.endpoint}thumbnail"
 
 
 def test_raster_info(api, mock_raster_data):
@@ -247,8 +249,25 @@ def test_get_content(api, mock_raster_data):
 def test_get_render_png_url(api, mock_raster_data):
     """Test getting tile PNG URL."""
     raster = Raster(api, uuid=mock_raster_data['uuid'], data=mock_raster_data)
-    url = raster.get_render_png_url(x=10, y=20, z=1)
-    assert url == f"{raster.api.base_url}{raster.endpoint}render/1/10/20.png"
+    url = raster.get_render_png_url(x=10, y=20, z=1, indexes=1)
+    assert url == f"{raster.api.base_url}{raster.endpoint}render/1/10/20.png?indexes=1"
+    # apikey
+    api.access_token = ''
+    api.apikey = 'apikey_1234'
+    url = raster.get_render_png_url(x=10, y=20, z=1, indexes=1)
+    assert url == f"{raster.api.base_url}{raster.endpoint}render/1/10/20.png?indexes=1&apikey=apikey_1234"
+    
+
+def test_get_tile_png_url(api, mock_raster_data):
+    """Test getting tile PNG URL."""
+    raster = Raster(api, uuid=mock_raster_data['uuid'], data=mock_raster_data)
+    url = raster.get_tile_png_url(x=10, y=20, z=1)
+    assert url == f"{raster.api.base_url}{raster.endpoint}tiles/1/10/20.png"
+    # apikey
+    api.access_token = ''
+    api.apikey = 'apikey_1234'
+    url = raster.get_tile_png_url(x=10, y=20, z=1)
+    assert url == f"{raster.api.base_url}{raster.endpoint}tiles/1/10/20.png?apikey=apikey_1234"
 
 
 def test_get_tile_pbf_url(api, mock_raster_data):
@@ -256,6 +275,11 @@ def test_get_tile_pbf_url(api, mock_raster_data):
     raster = Raster(api, uuid=mock_raster_data['uuid'], data=mock_raster_data)
     url = raster.get_tile_pbf_url(x=10, y=20, z=1)
     assert url == f"{raster.api.base_url}{raster.endpoint}tiles/1/10/20.pbf"
+    # apikey
+    api.access_token = ''
+    api.apikey = 'apikey_1234'
+    url = raster.get_tile_pbf_url(x=10, y=20, z=1)
+    assert url == f"{raster.api.base_url}{raster.endpoint}tiles/1/10/20.pbf?apikey=apikey_1234"
 
 
 def test_get_tile_json(api, mock_raster_data):
@@ -272,6 +296,11 @@ def test_wmts(api, mock_raster_data):
     raster = Raster(api, uuid=mock_raster_data['uuid'], data=mock_raster_data)
     url = raster.wmts(scale=1)
     assert url == f'{raster.api.base_url}{raster.endpoint}wmts/?scale=1'
+    # apikey
+    api.access_token = ''
+    api.apikey = 'apikey_1234'
+    url = raster.wmts(scale=1)
+    assert url == f'{raster.api.base_url}{raster.endpoint}wmts/?scale=1&apikey=apikey_1234'
 
 
 def test_settings(api, mock_raster_data):
@@ -283,6 +312,15 @@ def test_settings(api, mock_raster_data):
     api.get.assert_called_once_with(f'{raster.endpoint}settings/?f=json')
 
 
+def test_update_settings(api, mock_raster_data):
+    raster1 = Raster(api, uuid=mock_raster_data['uuid'], data=mock_raster_data)
+    raster2 = Raster(api, uuid=mock_raster_data['uuid'], data=mock_raster_data)
+    settings = raster2.settings
+    api.put.return_value = settings
+    raster1.update_settings(raster2.settings)
+    api.put.assert_called_once_with(f'{raster1.endpoint}settings/', settings)
+
+
 def test_set_settings(api, mock_raster_data):
     """Test setting raster settings."""
     raster = Raster(api, uuid=mock_raster_data['uuid'], data=mock_raster_data)
@@ -429,4 +467,18 @@ def test_cache_size(api, mock_raster_data):
     
     size = raster.cache_size
     assert size == 1024
-    api.post.assert_called_once_with(f"{raster.endpoint}cache/size/") 
\ No newline at end of file
+    api.post.assert_called_once_with(f"{raster.endpoint}cache/size/") 
+
+
+def test_to_async(api, async_api, mock_raster_data):
+    raster = Raster(api, uuid=mock_raster_data['uuid'], data=mock_raster_data)
+    async_instance = raster.to_async(async_api)
+    assert async_instance.api == async_api 
+
+
+def test_profile(api, mock_raster_data):
+    raster = Raster(api, uuid=mock_raster_data['uuid'], data=mock_raster_data)
+    api.post.return_value = {'key': 'value'}
+    result = raster.profile(polyline=[[0, 0], [10, 10]], number_of_samples=200)
+    assert result == {'key': 'value'}
+    api.post.assert_called_once_with(endpoint=f'rasters/{raster.uuid}/profile/', payload={'polyline': [[0, 0], [10, 10]], 'number_of_samples': 200, 'include_distance': True, 'treat_nodata_as_null': True})
\ No newline at end of file
