@@ -10,6 +10,7 @@ from geobox.enums import LayerType, TaskStatus
 from geobox.vectorlayer import VectorLayer
 from geobox.raster import Raster
 from geobox.model3d import Model
+from geobox.tile3d import Tile3d
 
 
 def test_init(api, mock_success_task_data):
@@ -26,7 +27,7 @@ def test_repr(api, mock_success_task_data):
     assert repr(task) == f"Task(uuid={task.uuid}, name={mock_success_task_data['name']})"
 
 
-def test_output_asset_property(api, mock_publish_task_data, mock_vector_data, mock_raster_data, mock_model_data, mock_file_data):
+def test_output_asset_property(api, mock_publish_task_data, mock_vector_data, mock_raster_data, mock_model_data, mock_file_data, mock_tile3d_data):
     # raster layer
     task = Task(api, uuid=mock_publish_task_data['uuid'], data=mock_publish_task_data)
     api.get_raster.return_value = Raster(api, mock_raster_data['uuid'], data=mock_raster_data)
@@ -66,9 +67,19 @@ def test_output_asset_property(api, mock_publish_task_data, mock_vector_data, mo
     assert task.output_asset.uuid == expected_layer.uuid
     assert task.output_asset.data == expected_layer.data
     assert type(task.output_asset) == File
+    # tile3d
+    mock_publish_task_data['result']['3dtiles_uuid'] = mock_publish_task_data['result']['file_uuid']
+    del mock_publish_task_data['result']['file_uuid']
+    task = Task(api, uuid=mock_publish_task_data['uuid'], data=mock_publish_task_data)
+    api.get_3dtile.return_value = Tile3d(api, mock_tile3d_data['uuid'], data=mock_tile3d_data)
+    expected_layer = Tile3d(api, mock_tile3d_data['uuid'], data=mock_tile3d_data)
+    assert task.output_asset.name == expected_layer.name
+    assert task.output_asset.uuid == expected_layer.uuid
+    assert task.output_asset.data == expected_layer.data
+    assert type(task.output_asset) == Tile3d
     #None
     mock_publish_task_data['name'] = 'import'
-    del mock_publish_task_data['result']['file_uuid']
+    del mock_publish_task_data['result']['3dtiles_uuid']
     task = Task(api, uuid=mock_publish_task_data['uuid'], data=mock_publish_task_data)
     assert task.output_asset == None
 
@@ -241,3 +252,9 @@ def test_get_task(api, mock_success_task_data):
         assert task.uuid == mock_success_task_data['uuid']
         assert task.name == mock_success_task_data['name']
         assert task.data == mock_success_task_data
+
+
+def test_to_async(api, async_api, mock_success_task_data):
+    task = Task(api, uuid=mock_success_task_data['uuid'], data=mock_success_task_data)
+    async_instance = task.to_async(async_api)
+    assert async_instance.api == async_api
\ No newline at end of file
