@@ -273,12 +273,16 @@ def test_update_tileset_extent(api, mock_tileset_data):
         api.post.assert_called_once_with(endpoint)
 
 
-def test_get_tile(api, mock_tileset_data):
+def test_get_tile_pbf_url(api, mock_tileset_data):
     """Test getting tile from tileset."""
-    url = f"tilesets/{mock_tileset_data['uuid']}/tiles/1/1/1.pbf"
     tileset = Tileset(api, uuid=mock_tileset_data['uuid'], data=mock_tileset_data)
-    tile_url = tileset.get_tile(x=1, y=1, z=1)
-    assert tile_url == url
+    url = tileset.get_tile_pbf_url(x=1, y=1, z=1)
+    assert url == f"{api.base_url}{tileset.endpoint}tiles/1/1/1.pbf"
+    # apikey
+    api.access_token = ''
+    api.apikey = 'apikey_1234'
+    url = tileset.get_tile_pbf_url(x=1, y=1, z=1)
+    assert url == f"{api.base_url}{tileset.endpoint}tiles/1/1/1.pbf?apikey=apikey_1234"
 
 
 def test_seed_cache(api, mock_tileset_data, mock_success_task_data):
@@ -308,16 +312,16 @@ def test_update_cache(api, mock_tileset_data, mock_success_task_data):
 
     api.get.return_value = mock_success_task_data
 
-    task = tileset.update_cache()[0]
+    task = tileset.update_cache(from_zoom=0, to_zoom=2, extents=[[1, 2, 3, 4]], user_id=1)[0]
     assert isinstance(task, Task)
-    api.post.assert_called_once_with(f'{tileset.endpoint}cache/update/', {})
+    api.post.assert_called_once_with(f'{tileset.endpoint}cache/update/', {'from_zoom': 0, 'to_zoom': 2, 'extents': [[1, 2, 3, 4]], 'user_id': 1})
     # error
     api.post.return_value = [1, 2, 3]
 
     api.get.return_value = mock_success_task_data
 
     with pytest.raises(ValueError, match="Failed to update cache"):
-        task = tileset.update_cache()
+        task = tileset.update_cache(from_zoom=0, to_zoom=2)
         
 
 def test_clear_cache(api, mock_tileset_data):
@@ -335,3 +339,9 @@ def test_cache_size(api, mock_tileset_data):
     size = tileset.cache_size
     assert size == 1024
     api.post.assert_called_once_with(f'{tileset.endpoint}cache/size/')
+
+
+def test_to_async(api, async_api, mock_tileset_data):
+    tileset = Tileset(api, uuid=mock_tileset_data['uuid'], data=mock_tileset_data)
+    async_instance = tileset.to_async(async_api)
+    assert async_instance.api == async_api
\ No newline at end of file
