@@ -138,6 +138,12 @@ def test_renew_plan(api, mock_admin_user_data):
         api.post.assert_called_once_with(expected_endpoint)
 
 
+def test_user_to_async(api, async_api, mock_admin_user_data):
+    user = User(api, user_id=mock_admin_user_data['id'], data=mock_admin_user_data)
+    async_instance = user.to_async(async_api)
+    assert async_instance.api == async_api
+
+
 def test_session_repr(api, mock_admin_user_data, mock_session_data):
     user = User(api, user_id=mock_admin_user_data['id'], data=mock_admin_user_data)
     api.get.return_value = [mock_session_data, mock_session_data]
@@ -152,3 +158,11 @@ def test_close_seesion(api, mock_admin_user_data, mock_session_data):
     api.reset_mock()
     sessions[0].close()
     api.post.assert_called_once_with('users/165/sessions/3857eb38-69d8-4b3c-8f60-29bac352a8d9', {'user_id': 165, 'session_uuid': '3857eb38-69d8-4b3c-8f60-29bac352a8d9'})
+
+
+def test_session_to_async(api, async_api, mock_admin_user_data, mock_session_data):
+    user = User(api, user_id=mock_admin_user_data['id'], data=mock_admin_user_data)
+    api.get.return_value = [mock_session_data, mock_session_data]
+    sessions = user.get_sessions()
+    async_instance = sessions[0].to_async(async_api)
+    assert async_instance.user.api == async_api
\ No newline at end of file
