@@ -11,6 +11,7 @@ from geobox.view import VectorLayerView
 from geobox.user import User
 from geobox.task import Task
 from geobox.file import File
+from geobox.attachment import Attachment
 from geobox.exception import NotFoundError
 from geobox.utils import clean_data
 
@@ -592,11 +593,16 @@ def test_create_view(api, mock_vector_data, layer_type, mock_view_data):
 
 
 @pytest.mark.parametrize("layer_type", [type for type in LayerType])
-def test_get_tile(api, mock_vector_data, layer_type):
+def test_get_tile_pbf_url(api, mock_vector_data, layer_type):
     """Test getting a vector tile."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
-    endpoint = layer.get_tile(x=1, y=2, z=3)
-    assert endpoint == f'{layer.BASE_ENDPOINT}{layer.endpoint}tiles/3/1/2.pbf'
+    url = layer.get_tile_pbf_url(x=1, y=2, z=3)
+    assert url == f'{layer.api.base_url}{layer.endpoint}tiles/3/1/2.pbf'
+    # apikey
+    api.access_token = ''
+    api.apikey = 'apikey_1234'
+    url = layer.get_tile_pbf_url(x=1, y=2, z=3)
+    assert url == f'{layer.api.base_url}{layer.endpoint}tiles/3/1/2.pbf?apikey=apikey_1234'
 
 
 @pytest.mark.parametrize("layer_type", [type for type in LayerType])
@@ -619,6 +625,16 @@ def test_settings(api, mock_vector_data, layer_type):
     assert settings == {'settings': 'value'}
 
 
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
+def test_update_settings(api, mock_vector_data, layer_type):
+    layer1 = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
+    layer2 = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
+    settings = layer2.settings
+    api.put.return_value = settings
+    layer1.update_settings(layer2.settings)
+    api.put.assert_called_once_with(f'{layer1.endpoint}settings/', settings)
+
+
 @pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_set_settings(api, mock_vector_data, layer_type):
     """Test setting the settings of a layer."""
@@ -745,3 +761,33 @@ def test_prune_edited_areas(api, mock_vector_data, layer_type):
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
     layer.prune_edited_areas()
     api.post.assert_called_once_with(f'{layer.endpoint}prune/')
+
+
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
+def test_get_attachments(api, mock_vector_data, mock_attachment_data, layer_type):
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
+
+    api.get.return_value = [mock_attachment_data, mock_attachment_data, mock_attachment_data]
+
+    attachments = layer.get_attachments()
+    assert len(attachments) == 3
+    assert type(attachments[0]) == Attachment
+
+
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
+def test_create_attachment(api, mock_vector_data, mock_attachment_data, mock_file_data, layer_type):
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
+
+    file = File(api, uuid=mock_file_data['uuid'], data=mock_file_data)
+
+    api.post.return_value = mock_attachment_data
+    attachment = layer.create_attachment(name='test', loc_x=10, loc_y=10, file=file)
+    assert type(attachment) == Attachment
+    assert attachment.data == mock_attachment_data
+
+
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
+def test_to_async(api, async_api, mock_vector_data, layer_type):
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
+    async_instance = layer.to_async(async_api)
+    assert async_instance.api == async_api
