@@ -9,6 +9,7 @@ from geobox.field import Field, FieldType
 from geobox.exception import NotFoundError
 from geobox.task import Task
 from geobox.file import File
+from geobox.attachment import Attachment
 from geobox.utils import clean_data
 
 
@@ -520,7 +521,7 @@ def test_export_features(api, mock_view_data, layer_type, mock_success_task_data
 
 
 @pytest.mark.parametrize("layer_type", [type for type in LayerType])
-def test_get_tile(api, mock_view_data, layer_type):
+def test_get_tile_pbf_url(api, mock_view_data, layer_type):
     """Test getting a vector tile."""
     view = VectorLayerView(
         api=api,
@@ -528,8 +529,8 @@ def test_get_tile(api, mock_view_data, layer_type):
         layer_type=layer_type,
         data=mock_view_data
     )
-    endpoint = view.get_tile(x=1, y=2, z=3)
-    assert endpoint == f'{view.BASE_ENDPOINT}{view.endpoint}tiles/3/1/2.pbf'
+    endpoint = view.get_tile_pbf_url(x=1, y=2, z=3)
+    assert endpoint == f'{view.api.base_url}{view.endpoint}tiles/3/1/2.pbf'
 
 
 @pytest.mark.parametrize("layer_type", [type for type in LayerType])
@@ -562,6 +563,16 @@ def test_settings(api, mock_view_data, layer_type):
     assert settings == {'settings': 'value'}
 
 
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
+def test_update_settings(api, mock_view_data, layer_type):
+    view1 = VectorLayerView(api, uuid=mock_view_data['uuid'], data=mock_view_data, layer_type=layer_type)
+    view2 = VectorLayerView(api, uuid=mock_view_data['uuid'], data=mock_view_data, layer_type=layer_type)
+    settings = view2.settings
+    api.put.return_value = settings
+    view1.update_settings(view2.settings)
+    api.put.assert_called_once_with(f'{view1.endpoint}settings/', settings)
+
+
 @pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_set_settings(api, mock_view_data, layer_type):
     """Test setting the settings of a layer."""
@@ -711,4 +722,49 @@ def test_prune_edited_areas(api, mock_view_data, layer_type):
         data=mock_view_data
     )
     view.prune_edited_areas()
-    api.post.assert_called_once_with(f'{view.endpoint}prune/')
\ No newline at end of file
+    api.post.assert_called_once_with(f'{view.endpoint}prune/')
+
+
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
+def test_get_attachments(api, mock_view_data, mock_attachment_data, layer_type):
+    view = VectorLayerView(
+        api=api,
+        uuid=mock_view_data['uuid'],
+        layer_type=layer_type,
+        data=mock_view_data
+    )
+
+    api.get.return_value = [mock_attachment_data, mock_attachment_data, mock_attachment_data]
+
+    attachments = view.get_attachments()
+    assert len(attachments) == 3
+    assert type(attachments[0]) == Attachment
+
+
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
+def test_create_attachment(api, mock_view_data, mock_attachment_data, mock_file_data, layer_type):
+    view = VectorLayerView(
+        api=api,
+        uuid=mock_view_data['uuid'],
+        layer_type=layer_type,
+        data=mock_view_data
+    )
+
+    file = File(api, uuid=mock_file_data['uuid'], data=mock_file_data)
+
+    api.post.return_value = mock_attachment_data
+    attachment = view.create_attachment(name='test', loc_x=10, loc_y=10, file=file)
+    assert type(attachment) == Attachment
+    assert attachment.data == mock_attachment_data
+
+
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
+def test_to_async(api, async_api, mock_view_data, layer_type):
+    view = VectorLayerView(
+        api=api,
+        uuid=mock_view_data['uuid'],
+        layer_type=layer_type,
+        data=mock_view_data
+    )
+    async_instance = view.to_async(async_api)
+    assert async_instance.api == async_api
\ No newline at end of file
